/*---------------------------------------------------------------------------
 *
 * Copyright (c) 2016, congatec AG. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the BSD 2-clause license which 
 * accompanies this distribution. 
 *
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * See the BSD 2-clause license for more details.
 *
 * The full text of the license may be found at:        
 * http://opensource.org/licenses/BSD-2-Clause   
 *
 *---------------------------------------------------------------------------
 */

/*---------------------------------------------------------------------------
 *
 * $Header:   S:/CG/archives/CGTOOLS/CGUTIL/CGUTLCMN/cgpanel.h-arc   1.6   Sep 06 2016 15:54:44   congatec  $
 *
 * Contents: Common panel configuration implementation module definitions.
 *
 *---------------------------------------------------------------------------
 *
 *                      R E V I S I O N   H I S T O R Y
 *
 * $Log:   S:/CG/archives/CGTOOLS/CGUTIL/CGUTLCMN/cgpanel.h-arc  $
 * 
 *    Rev 1.6   Sep 06 2016 15:54:44   congatec
 * Added BSD header.
 * 
 *    Rev 1.5   May 31 2012 15:45:48   gartner
 * Updated variable definition to ease 64bit porting.
 * 
 *    Rev 1.4   Jul 02 2007 13:12:32   gartner
 * Added definition for function to delete OEM EPI data set entry.
 * 
 *    Rev 1.3   Oct 30 2006 15:29:14   gartner
 * Added new function prototypes.
 * 
 *    Rev 1.2   Jan 27 2006 12:31:34   gartner
 * Changed return code definitions. Added support for the restart parameter to the MPFA related EPI functions.
 * 
 *    Rev 1.1   Dec 19 2005 13:28:48   gartner
 * MOD001: Added routine to clear EPI EEPROM; added backlight control routines.
 * 
 *    Rev 1.0   Oct 04 2005 13:14:16   gartner
 * Initial revision.
 * 
 *    Rev 1.0   Sep 30 2005 16:31:18   gartner
 * Initial revision.
 *
 *---------------------------------------------------------------------------
 */

#ifndef _INC_CGPANEL

#ifdef __cplusplus
extern "C" {
#endif 

#if (_MSC_VER <= 600)
#define __cdecl     _cdecl
#define __far       _far
#endif 

#include "cgbmod.h"
#include "cgepi.h"

//+---------------------------------------------------------------------------
//      Interface functions
//+---------------------------------------------------------------------------
extern uint16_t CgEpiStart(void);
extern uint16_t CgEpiEnd(void);

extern uint16_t CgEpiReadEpiFromMpfa(_TCHAR *pOutputFilename);
extern uint16_t CgEpiWriteEpiToMpfa(_TCHAR *pInputFilename, uint16_t bRestart);

extern uint16_t CgEpiReadEdidFromEEP(_TCHAR *pOutputFilename);
extern uint16_t CgEpiWriteEdidToEEP(_TCHAR *pInputFilename);
extern uint16_t CgEpiClearEEP(void);

extern uint16_t CgEpiReadOEMEdidFromMpfa(_TCHAR *pOutputFilename, uint16_t nOEMEdidNo);
extern uint16_t CgEpiReadStdEdidFromMpfa(_TCHAR *pOutputFilename, uint16_t nStdEdidNo);
extern uint16_t CgEpiWriteOEMEdidToMpfa(_TCHAR *pInputFilename, uint16_t nOEMEdidNo, uint16_t bRestart);
extern uint16_t CgEpiDelOEMEdidFromMpfa(uint16_t nOEMEdidNo, uint16_t bRestart);
extern uint16_t CgEpiGetEpiDataSetDesc(_TCHAR *lpszEpiDesc, uint16_t nStdEdidNo,uint16_t bOemSelect);

extern uint16_t CgEpiSetBLValue(uint32_t valueBL);
extern uint16_t CgEpiGetBLValue(uint32_t *pValueBL);
extern uint16_t CgEpiSetBLEnable(uint32_t stateBL);
extern uint16_t CgEpiGetBLEnable(uint32_t *pStateBL);
//+---------------------------------------------------------------------------
//       EPI module return codes
//+---------------------------------------------------------------------------
#define CG_EPIRET_OK            CG_MPFARET_OK           // Success
#define CG_EPIRET_ERROR         CG_MPFARET_ERROR        // General error
#define CG_EPIRET_INTRF_ERROR   CG_MPFARET_INTRF_ERROR  // Interface access/init. error
#define CG_EPIRET_INCOMP        CG_MPFARET_INCOMP       // Data incompatibility error
#define CG_EPIRET_NOTFOUND      CG_MPFARET_NOTFOUND     // Data not found error
#define CG_EPIRET_INV           CG_MPFARET_INV          // Invalid data
#define CG_EPIRET_ERROR_SIZE    CG_MPFARET_ERROR_SIZE   // Size exceeded
#define CG_EPIRET_ERROR_DUP     CG_MPFARET_ERROR_DUP    // Duplicate module exists error
#define CG_EPIRET_ERROR_FILE    CG_MPFARET_ERROR_FILE   // File processing error
#define CG_EPIRET_NOTALLOWED    CG_MPFARET_NOTALLOWED   // Operation not allowed
#define CG_EPIRET_INV_DATA      CG_MPFARET_INV_DATA     // Invalid MPFA module data
#define CG_EPIRET_INV_PARM      CG_MPFARET_INV_PARM     // Invalid MPFA module parameters


#ifdef __cplusplus
}
#endif 

#define _INC_CGPANEL
#endif 


