/*
 * Copyright (C) 2020 Hottinger Bruel & Kjaer Benelux B.V.
 * Schutweg 15a
 * 5145 NP Waalwijk
 * The Netherlands
 * http://www.hbm.com
 * All rights reserved
 *
 * The copyright to the computer program(s) herein is the property of
 * Hottinger Bruel & Kjaer Benelux B.V., Netherlands. The code/program(s)
 * may be used and/or copied only with the written permission of 
 * Hottinger Bruel & Kjaer Benelux B.V. or in accordance with the terms 
 * and conditions stipulated in the agreement/contract under which the 
 * program(s) have been supplied.
 * This copyright notice must not be removed.
 *
 * This Source Code is subject to the
 * "General supply and license conditions for software"
 * which is part of the standard terms and conditions of sale from 
 * Hottinger Bruel & Kjaer Benelux B.V..
 */

#include <linux/kernel.h>  /* For ARRAY_SIZE */
#include <linux/bug.h>     /* For ARRAY_SIZE */
#include <linux/types.h>

#include "fonts.h"


#define EXTENDED_ASCII


/* Font character bitmap data */
#ifdef EXTENDED_ASCII
static const u8  rom8x8__0x00[] ={
		/* Code 0x00, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0x01[] ={
		/* Code 0x01, ht=8, width=8
		 +--------+
		 | ****** |
		 |*      *|
		 |* *  * *|
		 |*      *|
		 |* **** *|
		 |*  **  *|
		 |*      *|
		 | ****** |
		 +--------+ */
	0x7e,
	0x81,
	0xa5,
	0x81,
	0xbd,
	0x99,
	0x81,
	0x7e
};

static const u8  rom8x8__0x02[] ={
		/* Code 0x02, ht=8, width=8
		 +--------+
		 | *****  |
		 |******* |
		 |** * ** |
		 |* *** * |
		 |**   ** |
		 |******* |
		 | *****  |
		 |        |
		 +--------+ */
	0x7c,
	0xfe,
	0xd6,
	0xba,
	0xc6,
	0xfe,
	0x7c,
	0x00
};

static const u8  rom8x8__0x03[] ={
		/* Code 0x03, ht=8, width=8
		 +--------+
		 |**   ** |
		 |*** *** |
		 |******* |
		 |******* |
		 | *****  |
		 |  ***   |
		 |   *    |
		 |        |
		 +--------+ */
	0xc6,
	0xee,
	0xfe,
	0xfe,
	0x7c,
	0x38,
	0x10,
	0x00
};

static const u8  rom8x8__0x04[] ={
		/* Code 0x04, ht=8, width=8
		 +--------+
		 |   *    |
		 |  ***   |
		 | *****  |
		 |******* |
		 | *****  |
		 |  ***   |
		 |   *    |
		 |        |
		 +--------+ */
	0x10,
	0x38,
	0x7c,
	0xfe,
	0x7c,
	0x38,
	0x10,
	0x00
};

static const u8  rom8x8__0x05[] ={
		/* Code 0x05, ht=8, width=8
		 +--------+
		 |   *    |
		 |  ***   |
		 |   *    |
		 |*** *** |
		 |*** *** |
		 |   *    |
		 |  ***   |
		 |        |
		 +--------+ */
	0x10,
	0x38,
	0x10,
	0xee,
	0xee,
	0x10,
	0x38,
	0x00
};

static const u8  rom8x8__0x06[] ={
		/* Code 0x06, ht=8, width=8
		 +--------+
		 |  ***   |
		 | *****  |
		 |******* |
		 |******* |
		 | ** **  |
		 |   *    |
		 |  ***   |
		 |        |
		 +--------+ */
	0x38,
	0x7c,
	0xfe,
	0xfe,
	0x6c,
	0x10,
	0x38,
	0x00
};

static const u8  rom8x8__0x07[] ={
		/* Code 0x07, ht=8, width=8
		 +--------+
		 |        |
		 |   **   |
		 |  ****  |
		 | ****** |
		 |  ****  |
		 |   **   |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x18,
	0x3c,
	0x7e,
	0x3c,
	0x18,
	0x00,
	0x00
};

static const u8  rom8x8__0x08[] ={
		/* Code 0x08, ht=8, width=8
		 +--------+
		 |********|
		 |***  ***|
		 |**    **|
		 |*      *|
		 |**    **|
		 |***  ***|
		 |********|
		 |********|
		 +--------+ */
	0xff,
	0xe7,
	0xc3,
	0x81,
	0xc3,
	0xe7,
	0xff,
	0xff
};

static const u8  rom8x8__0x09[] ={
		/* Code 0x09, ht=8, width=8
		 +--------+
		 |        |
		 |   **   |
		 |  ****  |
		 | **  ** |
		 | **  ** |
		 |  ****  |
		 |   **   |
		 |        |
		 +--------+ */
	0x00,
	0x18,
	0x3c,
	0x66,
	0x66,
	0x3c,
	0x18,
	0x00
};

static const u8  rom8x8__0x0a[] ={
		/* Code 0x0a, ht=8, width=8
		 +--------+
		 |********|
		 |***  ***|
		 |**    **|
		 |*  **  *|
		 |*  **  *|
		 |**    **|
		 |***  ***|
		 |********|
		 +--------+ */
	0xff,
	0xe7,
	0xc3,
	0x99,
	0x99,
	0xc3,
	0xe7,
	0xff
};

static const u8  rom8x8__0x0b[] ={
		/* Code 0x0b, ht=8, width=8
		 +--------+
		 |   **** |
		 |    *** |
		 |   **** |
		 |  ** ** |
		 | ****   |
		 |**  **  |
		 |**  **  |
		 | ****   |
		 +--------+ */
	0x1e,
	0x0e,
	0x1e,
	0x36,
	0x78,
	0xcc,
	0xcc,
	0x78
};

static const u8  rom8x8__0x0c[] ={
		/* Code 0x0c, ht=8, width=8
		 +--------+
		 | ****** |
		 |**    **|
		 |**    **|
		 | ****** |
		 |   **   |
		 | ****** |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x7e,
	0xc3,
	0xc3,
	0x7e,
	0x18,
	0x7e,
	0x18,
	0x18
};

static const u8  rom8x8__0x0d[] ={
		/* Code 0x0d, t=8, width=8
		 +--------+
		 |   **** |
		 |   ** * |
		 |   **** |
		 |   **   |
		 |   **   |
		 | ***    |
		 |****    |
		 | **     |
		 +--------+ */
	0x1e,
	0x1a,
	0x1e,
	0x18,
	0x18,
	0x70,
	0xf0,
	0x60
};

static const u8  rom8x8__0x0e[] ={
		/* Code 0x0e, ht=8, width=8
		 +--------+
		 |  ***** |
		 |  ***** |
		 |  ** ** |
		 |  ** ** |
		 |**** ** |
		 | **  ** |
		 |   **** |
		 |    **  |
		 +--------+ */
	0x3e,
	0x3e,
	0x36,
	0x36,
	0xf6,
	0x66,
	0x1e,
	0x0c
};

static const u8  rom8x8__0x0f[] ={
		/* Code 0x0f, ht=8, width=8
		 +--------+
		 |** ** **|
		 |  ****  |
		 | **  ** |
		 |***  ***|
		 | **  ** |
		 |  ****  |
		 |** ** **|
		 |        |
		 +--------+ */
	0xdb,
	0x3c,
	0x66,
	0xe7,
	0x66,
	0x3c,
	0xdb,
	0x00
};

static const u8  rom8x8__0x10[] ={
		/* Code 0x10, ht=8, width=8
		 +--------+
		 |*       |
		 |**      |
		 |****    |
		 |*****   |
		 |****    |
		 |**      |
		 |*       |
		 |        |
		 +--------+ */
	0x80,
	0xc0,
	0xf0,
	0xf8,
	0xf0,
	0xc0,
	0x80,
	0x00
};

static const u8  rom8x8__0x11[] ={
		/* Code 0x11, ht=8, width=8
		 +--------+
		 |      * |
		 |     ** |
		 |   **** |
		 |  ***** |
		 |   **** |
		 |     ** |
		 |      * |
		 |        |
		 +--------+ */
	0x02,
	0x06,
	0x1e,
	0x3e,
	0x1e,
	0x06,
	0x02,
	0x00
};

static const u8  rom8x8__0x12[] ={
		/* Code 0x12, ht=8, width=8
		 +--------+
		 |   **   |
		 |  ****  |
		 | ****** |
		 |   **   |
		 | ****** |
		 |  ****  |
		 |   **   |
		 |        |
		 +--------+ */
	0x18,
	0x3c,
	0x7e,
	0x18,
	0x7e,
	0x3c,
	0x18,
	0x00
};

static const u8  rom8x8__0x13[] ={
		/* Code 0x13, ht=8, width=8
		 +--------+
		 | **  ** |
		 | **  ** |
		 | **  ** |
		 | **  ** |
		 | **  ** |
		 |        |
		 | **  ** |
		 |        |
		 +--------+ */
	0x66,
	0x66,
	0x66,
	0x66,
	0x66,
	0x00,
	0x66,
	0x00
};

static const u8  rom8x8__0x14[] ={
		/* Code 0x14, ht=8, width=8
		 +--------+
		 | *******|
		 |** ** **|
		 | **** **|
		 |  *** **|
		 |   ** **|
		 |   ** **|
		 |   ** **|
		 |        |
		 +--------+ */
	0x7f,
	0xdb,
	0x7b,
	0x3b,
	0x1b,
	0x1b,
	0x1b,
	0x00
};

static const u8  rom8x8__0x15[] ={
		/* Code 0x15, ht=8, width=8
		 +--------+
		 |  ****  |
		 | **  ** |
		 |  ***   |
		 | ** **  |
		 | ** **  |
		 |  ***   |
		 |**  **  |
		 | ****   |
		 +--------+ */
	0x3c,
	0x66,
	0x38,
	0x6c,
	0x6c,
	0x38,
	0xcc,
	0x78
};

static const u8  rom8x8__0x16[] ={
		/* Code 0x16, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |******* |
		 |******* |
		 |******* |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0xfe,
	0xfe,
	0xfe,
	0x00
};

static const u8  rom8x8__0x17[] ={
		/* Code 0x17, ht=8, width=8
		 +--------+
		 |   **   |
		 |  ****  |
		 | ****** |
		 |   **   |
		 | ****** |
		 |  ****  |
		 |   **   |
		 | ****** |
		 +--------+ */
	0x18,
	0x3c,
	0x7e,
	0x18,
	0x7e,
	0x3c,
	0x18,
	0x7e
};

static const u8  rom8x8__0x18[] ={
		/* Code 0x18, ht=8, width=8
		 +--------+
		 |   **   |
		 |  ****  |
		 | ****** |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |        |
		 +--------+ */
	0x18,
	0x3c,
	0x7e,
	0x18,
	0x18,
	0x18,
	0x18,
	0x00
};

static const u8  rom8x8__0x19[] ={
		/* Code 0x19, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 | ****** |
		 |  ****  |
		 |   **   |
		 |        |
		 +--------+ */
	0x18,
	0x18,
	0x18,
	0x18,
	0x7e,
	0x3c,
	0x18,
	0x00
};

static const u8  rom8x8__0x1a[] ={
		/* Code 0x1a,  ht=8, width=8
		 +--------+
		 |        |
		 |   **   |
		 |   ***  |
		 |******* |
		 |   ***  |
		 |   **   |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x18,
	0x1c,
	0xfe,
	0x1c,
	0x18,
	0x00,
	0x00
};

static const u8  rom8x8__0x1b[] ={
		/* Code 0x1b, ht=8, width=8
		 +--------+
		 |        |
		 |  **    |
		 | ***    |
		 |******* |
		 | ***    |
		 |  **    |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x30,
	0x70,
	0xfe,
	0x70,
	0x30,
	0x00,
	0x00
};

static const u8  rom8x8__0x1c[] ={
		/* Code 0x1c, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |**      |
		 |**      |
		 |**      |
		 |******* |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0xc0,
	0xc0,
	0xc0,
	0xfe,
	0x00,
	0x00
};

static const u8  rom8x8__0x1d[] ={
		/* Code 0x1d, ht=8, width=8
		 +--------+
		 |        |
		 |  *  *  |
		 | **  ** |
		 |********|
		 | **  ** |
		 |  *  *  |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x24,
	0x66,
	0xff,
	0x66,
	0x24,
	0x00,
	0x00
};

static const u8  rom8x8__0x1e[] ={
		/* Code 0x1e, ht=8, width=8
		 +--------+
		 |        |
		 |   *    |
		 |  ***   |
		 | *****  |
		 | *****  |
		 |******* |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x10,
	0x38,
	0x7c,
	0x7c,
	0xfe,
	0x00,
	0x00
};

static const u8  rom8x8__0x1f[] ={
		/* Code 0x1f, ht=8, width=8
		 +--------+
		 |        |
		 |******* |
		 | *****  |
		 | *****  |
		 |  ***   |
		 |   *    |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0xfe,
	0x7c,
	0x7c,
	0x38,
	0x10,
	0x00,
	0x00
};
#endif /* EXTENDED_ASCII */

static const u8  rom8x8__0x20[] ={
		/* Code 0x20, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0x21[] ={
		/* Code 0x21, ht=8, width=8
		 +--------+
		 |   **   |
		 |  ****  |
		 |  ****  |
		 |   **   |
		 |   **   |
		 |        |
		 |   **   |
		 |        |
		 +--------+ */
	0x18,
	0x3c,
	0x3c,
	0x18,
	0x18,
	0x00,
	0x18,
	0x00
};

static const u8  rom8x8__0x22[] ={
		/* Code 0x22, ht=8, width=8
		 +--------+
		 | ** **  |
		 | ** **  |
		 | ** **  |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x6c,
	0x6c,
	0x6c,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0x23[] ={
		/* Code 0x23, ht=8, width=8
		 +--------+
		 | ** **  |
		 | ** **  |
		 |******* |
		 | ** **  |
		 |******* |
		 | ** **  |
		 | ** **  |
		 |        |
		 +--------+ */
	0x6c,
	0x6c,
	0xfe,
	0x6c,
	0xfe,
	0x6c,
	0x6c,
	0x00
};

static const u8  rom8x8__0x24[] ={
		/* Code 0x24, ht=8, width=8
		 +--------+
		 |   **   |
		 | ****** |
		 |**      |
		 | *****  |
		 |     ** |
		 |******  |
		 |   **   |
		 |        |
		 +--------+ */
	0x18,
	0x7e,
	0xc0,
	0x7c,
	0x06,
	0xfc,
	0x18,
	0x00
};

static const u8  rom8x8__0x25[] ={
		/* Code 0x25, ht=8, width=8
		 +--------+
		 |        |
		 |**   ** |
		 |    **  |
		 |   **   |
		 |  **    |
		 | **     |
		 |**   ** |
		 |        |
		 +--------+ */
	0x00,
	0xc6,
	0x0c,
	0x18,
	0x30,
	0x60,
	0xc6,
	0x00
};

static const u8  rom8x8__0x26[] ={
		/* Code 0x26, ht=8, width=8
		 +--------+
		 |  ***   |
		 | ** **  |
		 |  ***   |
		 | *** ** |
		 |**  **  |
		 |**  **  |
		 | *** ** |
		 |        |
		 +--------+ */
	0x38,
	0x6c,
	0x38,
	0x76,
	0xcc,
	0xcc,
	0x76,
	0x00
};

static const u8  rom8x8__0x27[] ={
		/* Code 0x27, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |  **    |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x18,
	0x18,
	0x30,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0x28[] ={
		/* Code 0x28, ht=8, width=8
		 +--------+
		 |   **   |
		 |  **    |
		 | **     |
		 | **     |
		 | **     |
		 |  **    |
		 |   **   |
		 |        |
		 +--------+ */
	0x18,
	0x30,
	0x60,
	0x60,
	0x60,
	0x30,
	0x18,
	0x00
};

static const u8  rom8x8__0x29[] ={
		/* Code 0x29, ht=8, width=8
		 +--------+
		 | **     |
		 |  **    |
		 |   **   |
		 |   **   |
		 |   **   |
		 |  **    |
		 | **     |
		 |        |
		 +--------+ */
	0x60,
	0x30,
	0x18,
	0x18,
	0x18,
	0x30,
	0x60,
	0x00
};

static const u8  rom8x8__0x2a[] ={
		/* Code 0x2a, ht=8, width=8
		 +--------+
		 |        |
		 |*** *** |
		 | *****  |
		 |******* |
		 | *****  |
		 |*** *** |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0xee,
	0x7c,
	0xfe,
	0x7c,
	0xee,
	0x00,
	0x00
};

static const u8  rom8x8__0x2b[] ={
		/* Code 0x2b, ht=8, width=8
		 +--------+
		 |        |
		 |   **   |
		 |   **   |
		 | ****** |
		 |   **   |
		 |   **   |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x18,
	0x18,
	0x7e,
	0x18,
	0x18,
	0x00,
	0x00
};

static const u8  rom8x8__0x2c[] ={
		/* Code 0x2c, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |   **   |
		 |   **   |
		 |  **    |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0x18,
	0x18,
	0x30,
	0x00
};

static const u8  rom8x8__0x2d[] ={
		/* Code 0x2d, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |******* |
		 |        |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0xfe,
	0x00,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0x2e[] ={
		/* Code 0x2e, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 |  ***   |
		 |  ***   |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0x00,
	0x38,
	0x38,
	0x00
};

static const u8  rom8x8__0x2f[] ={
		/* Code 0x2f, ht=8, width=8
		 +--------+
		 |     ** |
		 |    **  |
		 |   **   |
		 |  **    |
		 | **     |
		 |**      |
		 |*       |
		 |        |
		 +--------+ */
	0x06,
	0x0c,
	0x18,
	0x30,
	0x60,
	0xc0,
	0x80,
	0x00
};

static const u8  rom8x8__0x30[] ={
		/* Code 0x30, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |**  *** |
		 |** **** |
		 |**** ** |
		 |***  ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0xce,
	0xde,
	0xf6,
	0xe6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x31[] ={
		/* Code 0x31, ht=8, width=8
		 +--------+
		 |   **   |
		 | ****   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 | ****** |
		 |        |
		 +--------+ */
	0x18,
	0x78,
	0x18,
	0x18,
	0x18,
	0x18,
	0x7e,
	0x00
};

static const u8  rom8x8__0x32[] ={
		/* Code 0x32, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |    **  |
		 |   **   |
		 |  **    |
		 | **  ** |
		 |******* |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0x0c,
	0x18,
	0x30,
	0x66,
	0xfe,
	0x00
};

static const u8  rom8x8__0x33[] ={
		/* Code 0x33, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |     ** |
		 |  ****  |
		 |     ** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0x06,
	0x3c,
	0x06,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x34[] ={
		/* Code 0x34, ht=8, width=8
		 +--------+
		 |    **  |
		 |   ***  |
		 |  ****  |
		 | ** **  |
		 |******* |
		 |    **  |
		 |    **  |
		 |        |
		 +--------+ */
	0x0c,
	0x1c,
	0x3c,
	0x6c,
	0xfe,
	0x0c,
	0x0c,
	0x00
};

static const u8  rom8x8__0x35[] ={
		/* Code 0x35, ht=8, width=8
		 +--------+
		 |******* |
		 |**      |
		 |******  |
		 |     ** |
		 |     ** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0xfe,
	0xc0,
	0xfc,
	0x06,
	0x06,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x36[] ={
		/* Code 0x36, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |**      |
		 |******  |
		 |**   ** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0xc0,
	0xfc,
	0xc6,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x37[] ={
		/* Code 0x37, ht=8, width=8
		 +--------+
		 |******* |
		 |**   ** |
		 |     ** |
		 |    **  |
		 |   **   |
		 |   **   |
		 |   **   |
		 |        |
		 +--------+ */
	0xfe,
	0xc6,
	0x06,
	0x0c,
	0x18,
	0x18,
	0x18,
	0x00
};

static const u8  rom8x8__0x38[] ={
		/* Code 0x38, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |**   ** |
		 | *****  |
		 |**   ** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0xc6,
	0x7c,
	0xc6,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x39[] ={
		/* Code 0x39, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |**   ** |
		 | ****** |
		 |     ** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0xc6,
	0x7e,
	0x06,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x3a[] ={
		/* Code 0x3a, ht=8, width=8
		 +--------+
		 |        |
		 |   ***  |
		 |   ***  |
		 |        |
		 |        |
		 |   ***  |
		 |   ***  |
		 |        |
		 +--------+ */
	0x00,
	0x1c,
	0x1c,
	0x00,
	0x00,
	0x1c,
	0x1c,
	0x00
};

static const u8  rom8x8__0x3b[] ={
		/* Code 0x3b, ht=8, width=8
		 +--------+
		 |        |
		 |   **   |
		 |   **   |
		 |        |
		 |        |
		 |   **   |
		 |   **   |
		 |  **    |
		 +--------+ */
	0x00,
	0x18,
	0x18,
	0x00,
	0x00,
	0x18,
	0x18,
	0x30
};

static const u8  rom8x8__0x3c[] ={
		/* Code 0x3c, ht=8, width=8
		 +--------+
		 |    **  |
		 |   **   |
		 |  **    |
		 | **     |
		 |  **    |
		 |   **   |
		 |    **  |
		 |        |
		 +--------+ */
	0x0c,
	0x18,
	0x30,
	0x60,
	0x30,
	0x18,
	0x0c,
	0x00
};

static const u8  rom8x8__0x3d[] ={
		/* Code 0x3d, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |******* |
		 |        |
		 |        |
		 |******* |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0xfe,
	0x00,
	0x00,
	0xfe,
	0x00,
	0x00
};

static const u8  rom8x8__0x3e[] ={
		/* Code 0x3e, ht=8, width=8
		 +--------+
		 | **     |
		 |  **    |
		 |   **   |
		 |    **  |
		 |   **   |
		 |  **    |
		 | **     |
		 |        |
		 +--------+ */
	0x60,
	0x30,
	0x18,
	0x0c,
	0x18,
	0x30,
	0x60,
	0x00
};

static const u8  rom8x8__0x3f[] ={
		/* Code 0x3f, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |     ** |
		 |    **  |
		 |   **   |
		 |        |
		 |   **   |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0x06,
	0x0c,
	0x18,
	0x00,
	0x18,
	0x00
};

static const u8  rom8x8__0x40[] ={
		/* Code 0x40, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |**   ** |
		 |** **** |
		 |** ***  |
		 |**      |
		 | ****** |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0xc6,
	0xde,
	0xdc,
	0xc0,
	0x7e,
	0x00
};

static const u8  rom8x8__0x41[] ={
		/* Code 0x41, ht=8, width=8
		 +--------+
		 |  ***   |
		 | ** **  |
		 |**   ** |
		 |**   ** |
		 |******* |
		 |**   ** |
		 |**   ** |
		 |        |
		 +--------+ */
	0x38,
	0x6c,
	0xc6,
	0xc6,
	0xfe,
	0xc6,
	0xc6,
	0x00
};

static const u8  rom8x8__0x42[] ={
		/* Code 0x42, ht=8, width=8
		 +--------+
		 |******  |
		 | **  ** |
		 | **  ** |
		 | *****  |
		 | **  ** |
		 | **  ** |
		 |******  |
		 |        |
		 +--------+ */
	0xfc,
	0x66,
	0x66,
	0x7c,
	0x66,
	0x66,
	0xfc,
	0x00
};

static const u8  rom8x8__0x43[] ={
		/* Code 0x43, ht=8, width=8
		 +--------+
		 |  ****  |
		 | **  ** |
		 |**      |
		 |**      |
		 |**      |
		 | **  ** |
		 |  ****  |
		 |        |
		 +--------+ */
	0x3c,
	0x66,
	0xc0,
	0xc0,
	0xc0,
	0x66,
	0x3c,
	0x00
};

static const u8  rom8x8__0x44[] ={
		/* Code 0x44, ht=8, width=8
		 +--------+
		 |*****   |
		 | ** **  |
		 | **  ** |
		 | **  ** |
		 | **  ** |
		 | ** **  |
		 |*****   |
		 |        |
		 +--------+ */
	0xf8,
	0x6c,
	0x66,
	0x66,
	0x66,
	0x6c,
	0xf8,
	0x00
};

static const u8  rom8x8__0x45[] ={
		/* Code 0x45, ht=8, width=8
		 +--------+
		 |******* |
		 |**    * |
		 |**      |
		 |*****   |
		 |**      |
		 |**    * |
		 |******* |
		 |        |
		 +--------+ */
	0xfe,
	0xc2,
	0xc0,
	0xf8,
	0xc0,
	0xc2,
	0xfe,
	0x00
};

static const u8  rom8x8__0x46[] ={
		/* Code 0x46, ht=8, width=8
		 +--------+
		 |******* |
		 | **   * |
		 | **     |
		 | *****  |
		 | **     |
		 | **     |
		 |****    |
		 |        |
		 +--------+ */
	0xfe,
	0x62,
	0x60,
	0x7c,
	0x60,
	0x60,
	0xf0,
	0x00
};

static const u8  rom8x8__0x47[] ={
		/* Code 0x47, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |**      |
		 |**      |
		 |** **** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0xc0,
	0xc0,
	0xde,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x48[] ={
		/* Code 0x48, ht=8, width=8
		 +--------+
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |******* |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |        |
		 +--------+ */
	0xc6,
	0xc6,
	0xc6,
	0xfe,
	0xc6,
	0xc6,
	0xc6,
	0x00
};

static const u8  rom8x8__0x49[] ={
		/* Code 0x49, ht=8, width=8
		 +--------+
		 |  ****  |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |  ****  |
		 |        |
		 +--------+ */
	0x3c,
	0x18,
	0x18,
	0x18,
	0x18,
	0x18,
	0x3c,
	0x00
};

static const u8  rom8x8__0x4a[] ={
		/* Code 0x4a, ht=8, width=8
		 +--------+
		 |  ****  |
		 |   **   |
		 |   **   |
		 |   **   |
		 |** **   |
		 |** **   |
		 | ***    |
		 |        |
		 +--------+ */
	0x3c,
	0x18,
	0x18,
	0x18,
	0xd8,
	0xd8,
	0x70,
	0x00
};

static const u8  rom8x8__0x4b[] ={
		/* Code 0x4b, ht=8, width=8
		 +--------+
		 |**   ** |
		 |**  **  |
		 |** **   |
		 |****    |
		 |** **   |
		 |**  **  |
		 |**   ** |
		 |        |
		 +--------+ */
	0xc6,
	0xcc,
	0xd8,
	0xf0,
	0xd8,
	0xcc,
	0xc6,
	0x00
};

static const u8  rom8x8__0x4c[] ={
		/* Code 0x4c, ht=8, width=8
		 +--------+
		 |****    |
		 | **     |
		 | **     |
		 | **     |
		 | **     |
		 | **   * |
		 |******* |
		 |        |
		 +--------+ */
	0xf0,
	0x60,
	0x60,
	0x60,
	0x60,
	0x62,
	0xfe,
	0x00
};

static const u8  rom8x8__0x4d[] ={
		/* Code 0x4d, ht=8, width=8
		 +--------+
		 |**   ** |
		 |*** *** |
		 |******* |
		 |** * ** |
		 |** * ** |
		 |**   ** |
		 |**   ** |
		 |        |
		 +--------+ */
	0xc6,
	0xee,
	0xfe,
	0xd6,
	0xd6,
	0xc6,
	0xc6,
	0x00
};

static const u8  rom8x8__0x4e[] ={
		/* Code 0x4e, ht=8, width=8
		 +--------+
		 |**   ** |
		 |***  ** |
		 |***  ** |
		 |**** ** |
		 |** **** |
		 |**  *** |
		 |**   ** |
		 |        |
		 +--------+ */
	0xc6,
	0xe6,
	0xe6,
	0xf6,
	0xde,
	0xce,
	0xc6,
	0x00
};

static const u8  rom8x8__0x4f[] ={
		/* Code 0x4f, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0xc6,
	0xc6,
	0xc6,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x50[] ={
		/* Code 0x50, ht=8, width=8
		 +--------+
		 |******  |
		 | **  ** |
		 | **  ** |
		 | *****  |
		 | **     |
		 | **     |
		 |****    |
		 |        |
		 +--------+ */
	0xfc,
	0x66,
	0x66,
	0x7c,
	0x60,
	0x60,
	0xf0,
	0x00
};

static const u8  rom8x8__0x51[] ={
		/* Code 0x51, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |** * ** |
		 | *****  |
		 |     ** |
		 +--------+ */
	0x7c,
	0xc6,
	0xc6,
	0xc6,
	0xc6,
	0xd6,
	0x7c,
	0x06
};

static const u8  rom8x8__0x52[] ={
		/* Code 0x52, ht=8, width=8
		 +--------+
		 |******  |
		 |**   ** |
		 |**   ** |
		 |******  |
		 |** **   |
		 |**  **  |
		 |**   ** |
		 |        |
		 +--------+ */
	0xfc,
	0xc6,
	0xc6,
	0xfc,
	0xd8,
	0xcc,
	0xc6,
	0x00
};

static const u8  rom8x8__0x53[] ={
		/* Code 0x53, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |**      |
		 | *****  |
		 |     ** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0xc0,
	0x7c,
	0x06,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x54[] ={
		/* Code 0x54, ht=8, width=8
		 +--------+
		 | ****** |
		 | * ** * |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |  ****  |
		 |        |
		 +--------+ */
	0x7e,
	0x5a,
	0x18,
	0x18,
	0x18,
	0x18,
	0x3c,
	0x00
};

static const u8  rom8x8__0x55[] ={
		/* Code 0x55, ht=8, width=8
		 +--------+
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0xc6,
	0xc6,
	0xc6,
	0xc6,
	0xc6,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x56[] ={
		/* Code 0x56, ht=8, width=8
		 +--------+
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 | ** **  |
		 |  ***   |
		 |   *    |
		 |        |
		 +--------+ */
	0xc6,
	0xc6,
	0xc6,
	0xc6,
	0x6c,
	0x38,
	0x10,
	0x00
};

static const u8  rom8x8__0x57[] ={
		/* Code 0x57, ht=8, width=8
		 +--------+
		 |**   ** |
		 |**   ** |
		 |** * ** |
		 |** * ** |
		 |******* |
		 |*** *** |
		 |**   ** |
		 |        |
		 +--------+ */
	0xc6,
	0xc6,
	0xd6,
	0xd6,
	0xfe,
	0xee,
	0xc6,
	0x00
};

static const u8  rom8x8__0x58[] ={
		/* Code 0x58, ht=8, width=8
		 +--------+
		 |**   ** |
		 | ** **  |
		 |  ***   |
		 |  ***   |
		 |  ***   |
		 | ** **  |
		 |**   ** |
		 |        |
		 +--------+ */
	0xc6,
	0x6c,
	0x38,
	0x38,
	0x38,
	0x6c,
	0xc6,
	0x00
};

static const u8  rom8x8__0x59[] ={
		/* Code 0x59, ht=8, width=8
		 +--------+
		 | **  ** |
		 | **  ** |
		 | **  ** |
		 |  ****  |
		 |   **   |
		 |   **   |
		 |  ****  |
		 |        |
		 +--------+ */
	0x66,
	0x66,
	0x66,
	0x3c,
	0x18,
	0x18,
	0x3c,
	0x00
};

static const u8  rom8x8__0x5a[] ={
		/* Code 0x5a, ht=8, width=8
		 +--------+
		 |******* |
		 |*    ** |
		 |    **  |
		 |   **   |
		 |  **    |
		 | **   * |
		 |******* |
		 |        |
		 +--------+ */
	0xfe,
	0x86,
	0x0c,
	0x18,
	0x30,
	0x62,
	0xfe,
	0x00
};

static const u8  rom8x8__0x5b[] ={
		/* Code 0x5b, ht=8, width=8
		 +--------+
		 | *****  |
		 | **     |
		 | **     |
		 | **     |
		 | **     |
		 | **     |
		 | *****  |
		 |        |
		 +--------+ */
	0x7c,
	0x60,
	0x60,
	0x60,
	0x60,
	0x60,
	0x7c,
	0x00
};

static const u8  rom8x8__0x5c[] ={
		/* Code 0x5c, ht=8, width=8
		 +--------+
		 |**      |
		 | **     |
		 |  **    |
		 |   **   |
		 |    **  |
		 |     ** |
		 |      * |
		 |        |
		 +--------+ */
	0xc0,
	0x60,
	0x30,
	0x18,
	0x0c,
	0x06,
	0x02,
	0x00
};

static const u8  rom8x8__0x5d[] ={
		/* Code 0x5d, ht=8, width=8
		 +--------+
		 | *****  |
		 |    **  |
		 |    **  |
		 |    **  |
		 |    **  |
		 |    **  |
		 | *****  |
		 |        |
		 +--------+ */
	0x7c,
	0x0c,
	0x0c,
	0x0c,
	0x0c,
	0x0c,
	0x7c,
	0x00
};

static const u8  rom8x8__0x5e[] ={
		/* Code 0x5e, ht=8, width=8
		 +--------+
		 |   *    |
		 |  ***   |
		 | ** **  |
		 |**   ** |
		 |        |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x10,
	0x38,
	0x6c,
	0xc6,
	0x00,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0x5f[] ={
		/* Code 0x5f, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 |********|
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00,
	0xff
};

static const u8  rom8x8__0x60[] ={
		/* Code 0x60, ht=8, width=8
		 +--------+
		 |  **    |
		 |  **    |
		 |   **   |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x30,
	0x30,
	0x18,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0x61[] ={
		/* Code 0x61, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 | ****   |
		 |    **  |
		 | *****  |
		 |**  **  |
		 | ****** |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x78,
	0x0c,
	0x7c,
	0xcc,
	0x7e,
	0x00
};

static const u8  rom8x8__0x62[] ={
		/* Code 0x62, ht=8, width=8
		 +--------+
		 |***     |
		 | **     |
		 | *****  |
		 | **  ** |
		 | **  ** |
		 | **  ** |
		 |******  |
		 |        |
		 +--------+ */
	0xe0,
	0x60,
	0x7c,
	0x66,
	0x66,
	0x66,
	0xfc,
	0x00
};

static const u8  rom8x8__0x63[] ={
		/* Code 0x63, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 | *****  |
		 |**   ** |
		 |**      |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x7c,
	0xc6,
	0xc0,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x64[] ={
		/* Code 0x64, ht=8, width=8
		 +--------+
		 |   ***  |
		 |    **  |
		 | *****  |
		 |**  **  |
		 |**  **  |
		 |**  **  |
		 | ****** |
		 |        |
		 +--------+ */
	0x1c,
	0x0c,
	0x7c,
	0xcc,
	0xcc,
	0xcc,
	0x7e,
	0x00
};

static const u8  rom8x8__0x65[] ={
		/* Code 0x65, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 | *****  |
		 |**   ** |
		 |******* |
		 |**      |
		 | *****  |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x7c,
	0xc6,
	0xfe,
	0xc0,
	0x7c,
	0x00
};

static const u8  rom8x8__0x66[] ={
		/* Code 0x66, ht=8, width=8
		 +--------+
		 |   ***  |
		 |  ** ** |
		 |  **    |
		 |******  |
		 |  **    |
		 |  **    |
		 | ****   |
		 |        |
		 +--------+ */
	0x1c,
	0x36,
	0x30,
	0xfc,
	0x30,
	0x30,
	0x78,
	0x00
};

static const u8  rom8x8__0x67[] ={
		/* Code 0x67, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 | *** ** |
		 |**  *** |
		 |**   ** |
		 | ****** |
		 |     ** |
		 | *****  |
		 +--------+ */
	0x00,
	0x00,
	0x76,
	0xce,
	0xc6,
	0x7e,
	0x06,
	0x7c
};

static const u8  rom8x8__0x68[] ={
		/* Code 0x68, ht=8, width=8
		 +--------+
		 |***     |
		 | **     |
		 | *****  |
		 | **  ** |
		 | **  ** |
		 | **  ** |
		 |***  ** |
		 |        |
		 +--------+ */
	0xe0,
	0x60,
	0x7c,
	0x66,
	0x66,
	0x66,
	0xe6,
	0x00
};

static const u8  rom8x8__0x69[] ={
		/* Code 0x69, ht=8, width=8
		 +--------+
		 |   **   |
		 |        |
		 |  ***   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |  ****  |
		 |        |
		 +--------+ */
	0x18,
	0x00,
	0x38,
	0x18,
	0x18,
	0x18,
	0x3c,
	0x00
};

static const u8  rom8x8__0x6a[] ={
		/* Code 0x6a, ht=8, width=8
		 +--------+
		 |    **  |
		 |        |
		 |   ***  |
		 |    **  |
		 |    **  |
		 |    **  |
		 |**  **  |
		 | ****   |
		 +--------+ */
	0x0c,
	0x00,
	0x1c,
	0x0c,
	0x0c,
	0x0c,
	0xcc,
	0x78
};

static const u8  rom8x8__0x6b[] ={
		/* Code 0x6b, ht=8, width=8
		 +--------+
		 |***     |
		 | **     |
		 | **  ** |
		 | ** **  |
		 | ****   |
		 | ** **  |
		 |***  ** |
		 |        |
		 +--------+ */
	0xe0,
	0x60,
	0x66,
	0x6c,
	0x78,
	0x6c,
	0xe6,
	0x00
};

static const u8  rom8x8__0x6c[] ={
		/* Code 0x6c, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   ***  |
		 |        |
		 +--------+ */
	0x18,
	0x18,
	0x18,
	0x18,
	0x18,
	0x18,
	0x1c,
	0x00
};

static const u8  rom8x8__0x6d[] ={
		/* Code 0x6d, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 | ** **  |
		 |******* |
		 |** * ** |
		 |** * ** |
		 |**   ** |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x6c,
	0xfe,
	0xd6,
	0xd6,
	0xc6,
	0x00
};

static const u8  rom8x8__0x6e[] ={
		/* Code 0x6e, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |** ***  |
		 | **  ** |
		 | **  ** |
		 | **  ** |
		 | **  ** |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0xdc,
	0x66,
	0x66,
	0x66,
	0x66,
	0x00
};

static const u8  rom8x8__0x6f[] ={
		/* Code 0x6f, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 | *****  |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x7c,
	0xc6,
	0xc6,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x70[] ={
		/* Code 0x70, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |** ***  |
		 | **  ** |
		 | **  ** |
		 | *****  |
		 | **     |
		 |****    |
		 +--------+ */
	0x00,
	0x00,
	0xdc,
	0x66,
	0x66,
	0x7c,
	0x60,
	0xf0
};

static const u8  rom8x8__0x71[] ={
		/* Code 0x71, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 | *** ** |
		 |**  **  |
		 |**  **  |
		 | *****  |
		 |    **  |
		 |   **** |
		 +--------+ */
	0x00,
	0x00,
	0x76,
	0xcc,
	0xcc,
	0x7c,
	0x0c,
	0x1e
};

static const u8  rom8x8__0x72[] ={
		/* Code 0x72, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |** ***  |
		 | **  ** |
		 | **     |
		 | **     |
		 |****    |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0xdc,
	0x66,
	0x60,
	0x60,
	0xf0,
	0x00
};

static const u8  rom8x8__0x73[] ={
		/* Code 0x73, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 | *****  |
		 |**      |
		 | *****  |
		 |     ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x7c,
	0xc0,
	0x7c,
	0x06,
	0x7c,
	0x00
};

static const u8  rom8x8__0x74[] ={
		/* Code 0x74, ht=8, width=8
		 +--------+
		 |  **    |
		 |  **    |
		 |******  |
		 |  **    |
		 |  **    |
		 |  ** ** |
		 |   ***  |
		 |        |
		 +--------+ */
	0x30,
	0x30,
	0xfc,
	0x30,
	0x30,
	0x36,
	0x1c,
	0x00
};

static const u8  rom8x8__0x75[] ={
		/* Code 0x75, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |**  **  |
		 |**  **  |
		 |**  **  |
		 |**  **  |
		 | *** ** |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0xcc,
	0xcc,
	0xcc,
	0xcc,
	0x76,
	0x00
};

static const u8  rom8x8__0x76[] ={
		/* Code 0x76, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |**   ** |
		 |**   ** |
		 | ** **  |
		 |  ***   |
		 |   *    |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0xc6,
	0xc6,
	0x6c,
	0x38,
	0x10,
	0x00
};

static const u8  rom8x8__0x77[] ={
		/* Code 0x77, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |**   ** |
		 |**   ** |
		 |** * ** |
		 |******* |
		 | ** **  |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0xc6,
	0xc6,
	0xd6,
	0xfe,
	0x6c,
	0x00
};

static const u8  rom8x8__0x78[] ={
		/* Code 0x78, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |**   ** |
		 | ** **  |
		 |  ***   |
		 | ** **  |
		 |**   ** |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0xc6,
	0x6c,
	0x38,
	0x6c,
	0xc6,
	0x00
};

static const u8  rom8x8__0x79[] ={
		/* Code 0x79, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |**   ** |
		 |**   ** |
		 |**  *** |
		 | *** ** |
		 |     ** |
		 | *****  |
		 +--------+ */
	0x00,
	0x00,
	0xc6,
	0xc6,
	0xce,
	0x76,
	0x06,
	0x7c
};

static const u8  rom8x8__0x7a[] ={
		/* Code 0x7a, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |******  |
		 |*  **   |
		 |  **    |
		 | **  *  |
		 |******  |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0xfc,
	0x98,
	0x30,
	0x64,
	0xfc,
	0x00
};

static const u8  rom8x8__0x7b[] ={
		/* Code 0x7b, ht=8, width=8
		 +--------+
		 |    *** |
		 |   **   |
		 |   **   |
		 | ***    |
		 |   **   |
		 |   **   |
		 |    *** |
		 |        |
		 +--------+ */
	0x0e,
	0x18,
	0x18,
	0x70,
	0x18,
	0x18,
	0x0e,
	0x00
};

static const u8  rom8x8__0x7c[] ={
		/* Code 0x7c, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |   **   |
		 |        |
		 |   **   |
		 |   **   |
		 |   **   |
		 |        |
		 +--------+ */
	0x18,
	0x18,
	0x18,
	0x00,
	0x18,
	0x18,
	0x18,
	0x00
};

static const u8  rom8x8__0x7d[] ={
		/* Code 0x7d, ht=8, width=8
		 +--------+
		 | ***    |
		 |   **   |
		 |   **   |
		 |    *** |
		 |   **   |
		 |   **   |
		 | ***    |
		 |        |
		 +--------+ */
	0x70,
	0x18,
	0x18,
	0x0e,
	0x18,
	0x18,
	0x70,
	0x00
};

static const u8  rom8x8__0x7e[] ={
		/* Code 0x7e, ht=8, width=8
		 +--------+
		 | *** ** |
		 |** ***  |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x76,
	0xdc,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0x7f[] ={
		/* Code 0x7f, ht=8, width=8
		 +--------+
		 |        |
		 |   *    |
		 |  ***   |
		 |  ***   |
		 | ** **  |
		 | ** **  |
		 |******* |
		 |        |
		 +--------+ */
	0x00,
	0x10,
	0x38,
	0x38,
	0x6c,
	0x6c,
	0xfe,
	0x00
};

#ifdef EXTENDED_ASCII
static const u8  rom8x8__0x80[] ={
		/* Code 0x80, ht=8, width=8
		 +--------+
		 |  ****  |
		 | **  ** |
		 |**      |
		 | **  ** |
		 |  ****  |
		 |   **   |
		 |**  **  |
		 | ****   |
		 +--------+ */
	0x3c,
	0x66,
	0xc0,
	0x66,
	0x3c,
	0x18,
	0xcc,
	0x78
};

static const u8  rom8x8__0x81[] ={
		/* Code 0x81, ht=8, width=8
		 +--------+
		 |        |
		 |**   ** |
		 |        |
		 |**   ** |
		 |**   ** |
		 |**  *** |
		 | *** ** |
		 |        |
		 +--------+ */
	0x00,
	0xc6,
	0x00,
	0xc6,
	0xc6,
	0xce,
	0x76,
	0x00
};

static const u8  rom8x8__0x82[] ={
		/* Code 0x82, ht=8, width=8
		 +--------+
		 |    *** |
		 |        |
		 | *****  |
		 |**   ** |
		 |******* |
		 |**      |
		 | *****  |
		 |        |
		 +--------+ */
	0x0e,
	0x00,
	0x7c,
	0xc6,
	0xfe,
	0xc0,
	0x7c,
	0x00
};

static const u8  rom8x8__0x83[] ={
		/* Code 0x83, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 | ****   |
		 |    **  |
		 | *****  |
		 |**  **  |
		 | ****** |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0x78,
	0x0c,
	0x7c,
	0xcc,
	0x7e,
	0x00
};

static const u8  rom8x8__0x84[] ={
		/* Code 0x84, ht=8, width=8
		 +--------+
		 |**   ** |
		 |        |
		 | ****   |
		 |    **  |
		 | *****  |
		 |**  **  |
		 | ****** |
		 |        |
		 +--------+ */
	0xc6,
	0x00,
	0x78,
	0x0c,
	0x7c,
	0xcc,
	0x7e,
	0x00
};

static const u8  rom8x8__0x85[] ={
		/* Code 0x85, ht=8, width=8
		 +--------+
		 |***     |
		 |        |
		 | ****   |
		 |    **  |
		 | *****  |
		 |**  **  |
		 | ****** |
		 |        |
		 +--------+ */
	0xe0,
	0x00,
	0x78,
	0x0c,
	0x7c,
	0xcc,
	0x7e,
	0x00
};

static const u8  rom8x8__0x86[] ={
		/* Code 0x86, ht=8, width=8
		 +--------+
		 |  ***   |
		 |  ***   |
		 | ****   |
		 |    **  |
		 | *****  |
		 |**  **  |
		 | ****** |
		 |        |
		 +--------+ */
	0x38,
	0x38,
	0x78,
	0x0c,
	0x7c,
	0xcc,
	0x7e,
	0x00
};

static const u8  rom8x8__0x87[] ={
		/* Code 0x87, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 | *****  |
		 |**      |
		 | *****  |
		 |   **   |
		 | ** **  |
		 |  ***   |
		 +--------+ */
	0x00,
	0x00,
	0x7c,
	0xc0,
	0x7c,
	0x18,
	0x6c,
	0x38
};

static const u8  rom8x8__0x88[] ={
		/* Code 0x88, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 | *****  |
		 |**   ** |
		 |******* |
		 |**      |
		 | *****  |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0x7c,
	0xc6,
	0xfe,
	0xc0,
	0x7c,
	0x00
};

static const u8  rom8x8__0x89[] ={
		/* Code 0x89, ht=8, width=8
		 +--------+
		 |**   ** |
		 |        |
		 | *****  |
		 |**   ** |
		 |******* |
		 |**      |
		 | *****  |
		 |        |
		 +--------+ */
	0xc6,
	0x00,
	0x7c,
	0xc6,
	0xfe,
	0xc0,
	0x7c,
	0x00
};

static const u8  rom8x8__0x8a[] ={
		/* Code 0x8a, ht=8, width=8
		 +--------+
		 |***     |
		 |        |
		 | *****  |
		 |**   ** |
		 |******* |
		 |**      |
		 | *****  |
		 |        |
		 +--------+ */
	0xe0,
	0x00,
	0x7c,
	0xc6,
	0xfe,
	0xc0,
	0x7c,
	0x00
};

static const u8  rom8x8__0x8b[] ={
		/* Code 0x8b, ht=8, width=8
		 +--------+
		 | **  ** |
		 |        |
		 |  ***   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |  ****  |
		 |        |
		 +--------+ */
	0x66,
	0x00,
	0x38,
	0x18,
	0x18,
	0x18,
	0x3c,
	0x00
};

static const u8  rom8x8__0x8c[] ={
		/* Code 0x8c, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |  ***   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |  ****  |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0x38,
	0x18,
	0x18,
	0x18,
	0x3c,
	0x00
};

static const u8  rom8x8__0x8d[] ={
		/* Code 0x8d, ht=8, width=8
		 +--------+
		 |***     |
		 |        |
		 |  ***   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |  ****  |
		 |        |
		 +--------+ */
	0xe0,
	0x00,
	0x38,
	0x18,
	0x18,
	0x18,
	0x3c,
	0x00
};

static const u8  rom8x8__0x8e[] ={
		/* Code 0x8e, ht=8, width=8
		 +--------+
		 |**   ** |
		 |  ***   |
		 | ** **  |
		 |**   ** |
		 |******* |
		 |**   ** |
		 |**   ** |
		 |        |
		 +--------+ */
	0xc6,
	0x38,
	0x6c,
	0xc6,
	0xfe,
	0xc6,
	0xc6,
	0x00
};

static const u8  rom8x8__0x8f[] ={
		/* Code 0x8f, ht=8, width=8
		 +--------+
		 |  ***   |
		 |  ***   |
		 |        |
		 | *****  |
		 |**   ** |
		 |******* |
		 |**   ** |
		 |        |
		 +--------+ */
	0x38,
	0x38,
	0x00,
	0x7c,
	0xc6,
	0xfe,
	0xc6,
	0x00
};

static const u8  rom8x8__0x90[] ={
		/* Code 0x90, ht=8, width=8
		 +--------+
		 |    *** |
		 |        |
		 |******* |
		 |**      |
		 |*****   |
		 |**      |
		 |******* |
		 |        |
		 +--------+ */
	0x0e,
	0x00,
	0xfe,
	0xc0,
	0xf8,
	0xc0,
	0xfe,
	0x00
};

static const u8  rom8x8__0x91[] ={
		/* Code 0x91, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 | ** **  |
		 |*  ** * |
		 | ****** |
		 |** **   |
		 | ** *** |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x6c,
	0x9a,
	0x7e,
	0xd8,
	0x6e,
	0x00
};

static const u8  rom8x8__0x92[] ={
		/* Code 0x92, ht=8, width=8
		 +--------+
		 | ****** |
		 |** **   |
		 |** **   |
		 |******* |
		 |** **   |
		 |** **   |
		 |** **** |
		 |        |
		 +--------+ */
	0x7e,
	0xd8,
	0xd8,
	0xfe,
	0xd8,
	0xd8,
	0xde,
	0x00
};

static const u8  rom8x8__0x93[] ={
		/* Code 0x93, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |        |
		 | *****  |
		 |**   ** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0x00,
	0x7c,
	0xc6,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x94[] ={
		/* Code 0x94, ht=8, width=8
		 +--------+
		 |        |
		 |**   ** |
		 |        |
		 | *****  |
		 |**   ** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x00,
	0xc6,
	0x00,
	0x7c,
	0xc6,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x95[] ={
		/* Code 0x95, ht=8, width=8
		 +--------+
		 |        |
		 |***     |
		 |        |
		 | *****  |
		 |**   ** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x00,
	0xe0,
	0x00,
	0x7c,
	0xc6,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x96[] ={
		/* Code 0x96, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |        |
		 |**   ** |
		 |**   ** |
		 |**  *** |
		 | *** ** |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0x00,
	0xc6,
	0xc6,
	0xce,
	0x76,
	0x00
};

static const u8  rom8x8__0x97[] ={
		/* Code 0x97, ht=8, width=8
		 +--------+
		 |        |
		 |***     |
		 |        |
		 |**   ** |
		 |**   ** |
		 |**  *** |
		 | *** ** |
		 |        |
		 +--------+ */
	0x00,
	0xe0,
	0x00,
	0xc6,
	0xc6,
	0xce,
	0x76,
	0x00
};

static const u8  rom8x8__0x98[] ={
		/* Code 0x98, ht=8, width=8
		 +--------+
		 |        |
		 |**   ** |
		 |        |
		 |**   ** |
		 |**  *** |
		 | *** ** |
		 |     ** |
		 | *****  |
		 +--------+ */
	0x00,
	0xc6,
	0x00,
	0xc6,
	0xce,
	0x76,
	0x06,
	0x7c
};

static const u8  rom8x8__0x99[] ={
		/* Code 0x99, ht=8, width=8
		 +--------+
		 |**   ** |
		 |  ***   |
		 | ** **  |
		 |**   ** |
		 |**   ** |
		 | ** **  |
		 |  ***   |
		 |        |
		 +--------+ */
	0xc6,
	0x38,
	0x6c,
	0xc6,
	0xc6,
	0x6c,
	0x38,
	0x00
};

static const u8  rom8x8__0x9a[] ={
		/* Code 0x9a, ht=8, width=8
		 +--------+
		 |**   ** |
		 |        |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0xc6,
	0x00,
	0xc6,
	0xc6,
	0xc6,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0x9b[] ={
		/* Code 0x9b, ht=8, width=8
		 +--------+
		 |        |
		 |   **   |
		 | ****** |
		 |** **   |
		 |** **   |
		 | ****** |
		 |   **   |
		 |        |
		 +--------+ */
	0x00,
	0x18,
	0x7e,
	0xd8,
	0xd8,
	0x7e,
	0x18,
	0x00
};

static const u8  rom8x8__0x9c[] ={
		/* Code 0x9c, ht=8, width=8
		 +--------+
		 |  ***   |
		 | ** **  |
		 | **     |
		 |****    |
		 | **  ** |
		 |**** ** |
		 | ** **  |
		 |        |
		 +--------+ */
	0x38,
	0x6c,
	0x60,
	0xf0,
	0x66,
	0xf6,
	0x6c,
	0x00
};

static const u8  rom8x8__0x9d[] ={
		/* Code 0x9d, ht=8, width=8
		 +--------+
		 |**    **|
		 | **  ** |
		 |  ****  |
		 | ****** |
		 |   **   |
		 |  ****  |
		 |   **   |
		 |        |
		 +--------+ */
	0xc3,
	0x66,
	0x3c,
	0x7e,
	0x18,
	0x3c,
	0x18,
	0x00
};

static const u8  rom8x8__0x9e[] ={
		/* Code 0x9e, ht=8, width=8
		 +--------+
		 |******  |
		 |**   ** |
		 |******  |
		 |**  **  |
		 |** **** |
		 |**  **  |
		 |**  *** |
		 |        |
		 +--------+ */
	0xfc,
	0xc6,
	0xfc,
	0xcc,
	0xde,
	0xcc,
	0xce,
	0x00
};

static const u8  rom8x8__0x9f[] ={
		/* Code 0x9f, ht=8, width=8
		 +--------+
		 |    **  |
		 |   **** |
		 |   **   |
		 | ****** |
		 |   **   |
		 |   **   |
		 |** **   |
		 | ***    |
		 +--------+ */
	0x0c,
	0x1e,
	0x18,
	0x7e,
	0x18,
	0x18,
	0xd8,
	0x70
};

static const u8  rom8x8__0xa0[] ={
		/* Code 0xa0, ht=8, width=8
		 +--------+
		 |    *** |
		 |        |
		 | ****   |
		 |    **  |
		 | *****  |
		 |**  **  |
		 | ****** |
		 |        |
		 +--------+ */
	0x0e,
	0x00,
	0x78,
	0x0c,
	0x7c,
	0xcc,
	0x7e,
	0x00
};

static const u8  rom8x8__0xa1[] ={
		/* Code 0xa1, ht=8, width=8
		 +--------+
		 |   ***  |
		 |        |
		 |  ***   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |  ****  |
		 |        |
		 +--------+ */
	0x1c,
	0x00,
	0x38,
	0x18,
	0x18,
	0x18,
	0x3c,
	0x00
};

static const u8  rom8x8__0xa2[] ={
		/* Code 0xa2, ht=8, width=8
		 +--------+
		 |        |
		 |    *** |
		 |        |
		 | *****  |
		 |**   ** |
		 |**   ** |
		 | *****  |
		 |        |
		 +--------+ */
	0x00,
	0x0e,
	0x00,
	0x7c,
	0xc6,
	0xc6,
	0x7c,
	0x00
};

static const u8  rom8x8__0xa3[] ={
		/* Code 0xa3, ht=8, width=8
		 +--------+
		 |        |
		 |    *** |
		 |        |
		 |**  **  |
		 |**  **  |
		 |** ***  |
		 | *** ** |
		 |        |
		 +--------+ */
	0x00,
	0x0e,
	0x00,
	0xcc,
	0xcc,
	0xdc,
	0x76,
	0x00
};

static const u8  rom8x8__0xa4[] ={
		/* Code 0xa4, ht=8, width=8
		 +--------+
		 |        |
		 |******  |
		 |        |
		 |* ****  |
		 | **  ** |
		 | **  ** |
		 |***  ** |
		 |        |
		 +--------+ */
	0x00,
	0xfc,
	0x00,
	0xbc,
	0x66,
	0x66,
	0xe6,
	0x00
};

static const u8  rom8x8__0xa5[] ={
		/* Code 0xa5, ht=8, width=8
		 +--------+
		 |******* |
		 |        |
		 |**   ** |
		 |***  ** |
		 |**** ** |
		 |**  *** |
		 |**   ** |
		 |        |
		 +--------+ */
	0xfe,
	0x00,
	0xc6,
	0xe6,
	0xf6,
	0xce,
	0xc6,
	0x00
};

static const u8  rom8x8__0xa6[] ={
		/* Code 0xa6, ht=8, width=8
		 +--------+
		 |  ***   |
		 | ** **  |
		 |  ***** |
		 |        |
		 | ****** |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x38,
	0x6c,
	0x3e,
	0x00,
	0x7e,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xa7[] ={
		/* Code 0xa7, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 | *****  |
		 |        |
		 | *****  |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0x7c,
	0x00,
	0x7c,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xa8[] ={
		/* Code 0xa8, ht=8, width=8
		 +--------+
		 |   **   |
		 |        |
		 |   **   |
		 |  **    |
		 | **     |
		 | **  ** |
		 |  ****  |
		 |        |
		 +--------+ */
	0x18,
	0x00,
	0x18,
	0x30,
	0x60,
	0x66,
	0x3c,
	0x00
};

static const u8  rom8x8__0xa9[] ={
		/* Code 0xa9, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 | *****  |
		 | **     |
		 | **     |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x7c,
	0x60,
	0x60,
	0x00,
	0x00
};

static const u8  rom8x8__0xaa[] ={
		/* Code 0xaa, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 | *****  |
		 |    **  |
		 |    **  |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x7c,
	0x0c,
	0x0c,
	0x00,
	0x00
};

static const u8  rom8x8__0xab[] ={
		/* Code 0xab, ht=8, width=8
		 +--------+
		 |**      |
		 |**  **  |
		 |** **   |
		 |  **    |
		 | *****  |
		 |  ** ** |
		 |    **  |
		 |  ***** |
		 +--------+ */
	0xc0,
	0xcc,
	0xd8,
	0x30,
	0x7c,
	0x36,
	0x0c,
	0x3e
};

static const u8  rom8x8__0xac[] ={
		/* Code 0xac, ht=8, width=8
		 +--------+
		 |**      |
		 |**  **  |
		 |** **   |
		 |  **    |
		 | ** **  |
		 |  ****  |
		 | ****** |
		 |    **  |
		 +--------+ */
	0xc0,
	0xcc,
	0xd8,
	0x30,
	0x6c,
	0x3c,
	0x7e,
	0x0c
};

static const u8  rom8x8__0xad[] ={
		/* Code 0xad, ht=8, width=8
		 +--------+
		 |   **   |
		 |        |
		 |   **   |
		 |   **   |
		 |  ****  |
		 |  ****  |
		 |   **   |
		 |        |
		 +--------+ */
	0x18,
	0x00,
	0x18,
	0x18,
	0x3c,
	0x3c,
	0x18,
	0x00
};

static const u8  rom8x8__0xae[] ={
		/* Code 0xae, ht=8, width=8
		 +--------+
		 |        |
		 |  ** ** |
		 | ** **  |
		 |** **   |
		 | ** **  |
		 |  ** ** |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x36,
	0x6c,
	0xd8,
	0x6c,
	0x36,
	0x00,
	0x00
};

static const u8  rom8x8__0xaf[] ={
		/* Code 0xaf, ht=8, width=8
		 +--------+
		 |        |
		 |** **   |
		 | ** **  |
		 |  ** ** |
		 | ** **  |
		 |** **   |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0xd8,
	0x6c,
	0x36,
	0x6c,
	0xd8,
	0x00,
	0x00
};

static const u8  rom8x8__0xb0[] ={
		/* Code 0xb0, ht=8, width=8
		 +--------+
		 |  *   * |
		 |*   *   |
		 |  *   * |
		 |*   *   |
		 |  *   * |
		 |*   *   |
		 |  *   * |
		 |*   *   |
		 +--------+ */
	0x22,
	0x88,
	0x22,
	0x88,
	0x22,
	0x88,
	0x22,
	0x88
};

static const u8  rom8x8__0xb1[] ={
		/* Code 0xb1, ht=8, width=8
		 +--------+
		 | * * * *|
		 |* * * * |
		 | * * * *|
		 |* * * * |
		 | * * * *|
		 |* * * * |
		 | * * * *|
		 |* * * * |
		 +--------+ */
	0x55,
	0xaa,
	0x55,
	0xaa,
	0x55,
	0xaa,
	0x55,
	0xaa
};

static const u8  rom8x8__0xb2[] ={
		/* Code 0xb2, ht=8, width=8
		 +--------+
		 |** *** *|
		 | *** ***|
		 |** *** *|
		 | *** ***|
		 |** *** *|
		 | *** ***|
		 |** *** *|
		 | *** ***|
		 +--------+ */
	0xdd,
	0x77,
	0xdd,
	0x77,
	0xdd,
	0x77,
	0xdd,
	0x77
};

static const u8  rom8x8__0xb3[] ={
		/* Code 0xb3, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x18,
	0x18,
	0x18,
	0x18,
	0x18,
	0x18,
	0x18,
	0x18
};

static const u8  rom8x8__0xb4[] ={
		/* Code 0xb4, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |*****   |
		 |   **   |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x18,
	0x18,
	0x18,
	0x18,
	0xf8,
	0x18,
	0x18,
	0x18
};

static const u8  rom8x8__0xb5[] ={
		/* Code 0xb5, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |*****   |
		 |   **   |
		 |*****   |
		 |   **   |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x18,
	0x18,
	0xf8,
	0x18,
	0xf8,
	0x18,
	0x18,
	0x18
};

static const u8  rom8x8__0xb6[] ={
		/* Code 0xb6, ht=8, width=8
		 +--------+
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |**** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 +--------+ */
	0x36,
	0x36,
	0x36,
	0x36,
	0xf6,
	0x36,
	0x36,
	0x36
};

static const u8  rom8x8__0xb7[] ={
		/* Code 0xb7, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |******* |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0xfe,
	0x36,
	0x36,
	0x36
};

static const u8  rom8x8__0xb8[] ={
		/* Code 0xb8, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |*****   |
		 |   **   |
		 |*****   |
		 |   **   |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x00,
	0x00,
	0xf8,
	0x18,
	0xf8,
	0x18,
	0x18,
	0x18
};

static const u8  rom8x8__0xb9[] ={
		/* Code 0xb9, ht=8, width=8
		 +--------+
		 |  ** ** |
		 |  ** ** |
		 |**** ** |
		 |     ** |
		 |**** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 +--------+ */
	0x36,
	0x36,
	0xf6,
	0x06,
	0xf6,
	0x36,
	0x36,
	0x36
};

static const u8  rom8x8__0xba[] ={
		/* Code 0xba, ht=8, width=8
		 +--------+
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 +--------+ */
	0x36,
	0x36,
	0x36,
	0x36,
	0x36,
	0x36,
	0x36,
	0x36
};

static const u8  rom8x8__0xbb[] ={
		/* Code 0xbb, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |******* |
		 |     ** |
		 |**** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 +--------+ */
	0x00,
	0x00,
	0xfe,
	0x06,
	0xf6,
	0x36,
	0x36,
	0x36
};

static const u8  rom8x8__0xbc[] ={
		/* Code 0xbc, ht=8, width=8
		 +--------+
		 |  ** ** |
		 |  ** ** |
		 |**** ** |
		 |     ** |
		 |******* |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x36,
	0x36,
	0xf6,
	0x06,
	0xfe,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xbd[] ={
		/* Code 0xbd, ht=8, width=8
		 +--------+
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |******* |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x36,
	0x36,
	0x36,
	0x36,
	0xfe,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xbe[] ={
		/* Code 0xbe, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |*****   |
		 |   **   |
		 |*****   |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x18,
	0x18,
	0xf8,
	0x18,
	0xf8,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xbf[] ={
		/* Code 0xbf, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |*****   |
		 |   **   |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0xf8,
	0x18,
	0x18,
	0x18
};

static const u8  rom8x8__0xc0[] ={
		/* Code 0xc0, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   *****|
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x18,
	0x18,
	0x18,
	0x18,
	0x1f,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xc1[] ={
		/* Code 0xc1, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |********|
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x18,
	0x18,
	0x18,
	0x18,
	0xff,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xc2[] ={
		/* Code 0xc2, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |********|
		 |   **   |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0xff,
	0x18,
	0x18,
	0x18
};

static const u8  rom8x8__0xc3[] ={
		/* Code 0xc3, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   *****|
		 |   **   |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x18,
	0x18,
	0x18,
	0x18,
	0x1f,
	0x18,
	0x18,
	0x18
};

static const u8  rom8x8__0xc4[] ={
		/* Code 0xc4, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |********|
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0xff,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xc5[] ={
		/* Code 0xc5, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |********|
		 |   **   |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x18,
	0x18,
	0x18,
	0x18,
	0xff,
	0x18,
	0x18,
	0x18
};

static const u8  rom8x8__0xc6[] ={
		/* Code 0xc6, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |   *****|
		 |   **   |
		 |   *****|
		 |   **   |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x18,
	0x18,
	0x1f,
	0x18,
	0x1f,
	0x18,
	0x18,
	0x18
};

static const u8  rom8x8__0xc7[] ={
		/* Code 0xc7, ht=8, width=8
		 +--------+
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ***|
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 +--------+ */
	0x36,
	0x36,
	0x36,
	0x36,
	0x37,
	0x36,
	0x36,
	0x36
};

static const u8  rom8x8__0xc8[] ={
		/* Code 0xc8, ht=8, width=8
		 +--------+
		 |  ** ** |
		 |  ** ** |
		 |  ** ***|
		 |  **    |
		 |  ******|
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x36,
	0x36,
	0x37,
	0x30,
	0x3f,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xc9[] ={
		/* Code 0xc9, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |  ******|
		 |  **    |
		 |  ** ***|
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 +--------+ */
	0x00,
	0x00,
	0x3f,
	0x30,
	0x37,
	0x36,
	0x36,
	0x36
};

static const u8  rom8x8__0xca[] ={
		/* Code 0xca, ht=8, width=8
		 +--------+
		 |  ** ** |
		 |  ** ** |
		 |**** ***|
		 |        |
		 |********|
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x36,
	0x36,
	0xf7,
	0x00,
	0xff,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xcb[] ={
		/* Code 0xcb, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |********|
		 |        |
		 |**** ***|
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 +--------+ */
	0x00,
	0x00,
	0xff,
	0x00,
	0xf7,
	0x36,
	0x36,
	0x36
};

static const u8  rom8x8__0xcc[] ={
		/* Code 0xcc, ht=8, width=8
		 +--------+
		 |  ** ** |
		 |  ** ** |
		 |  ** ***|
		 |  **    |
		 |  ** ***|
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 +--------+ */
	0x36,
	0x36,
	0x37,
	0x30,
	0x37,
	0x36,
	0x36,
	0x36
};

static const u8  rom8x8__0xcd[] ={
		/* Code 0xcd, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |********|
		 |        |
		 |********|
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0xff,
	0x00,
	0xff,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xce[] ={
		/* Code 0xce, ht=8, width=8
		 +--------+
		 |  ** ** |
		 |  ** ** |
		 |**** ***|
		 |        |
		 |**** ***|
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 +--------+ */
	0x36,
	0x36,
	0xf7,
	0x00,
	0xf7,
	0x36,
	0x36,
	0x36
};

static const u8  rom8x8__0xcf[] ={
		/* Code 0xcf, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |********|
		 |        |
		 |********|
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x18,
	0x18,
	0xff,
	0x00,
	0xff,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xd0[] ={
		/* Code 0xd0, ht=8, width=8
		 +--------+
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |********|
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x36,
	0x36,
	0x36,
	0x36,
	0xff,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xd1[] ={
		/* Code 0xd1, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |********|
		 |        |
		 |********|
		 |   **   |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x00,
	0x00,
	0xff,
	0x00,
	0xff,
	0x18,
	0x18,
	0x18
};

static const u8  rom8x8__0xd2[] ={
		/* Code 0xd2, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |********|
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0xff,
	0x36,
	0x36,
	0x36
};

static const u8  rom8x8__0xd3[] ={
		/* Code 0xd3, ht=8, width=8
		 +--------+
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ******|
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x36,
	0x36,
	0x36,
	0x36,
	0x3f,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xd4[] ={
		/* Code 0xd4, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |   *****|
		 |   **   |
		 |   *****|
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x18,
	0x18,
	0x1f,
	0x18,
	0x1f,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xd5[] ={
		/* Code 0xd5, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |   *****|
		 |   **   |
		 |   *****|
		 |   **   |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x00,
	0x00,
	0x1f,
	0x18,
	0x1f,
	0x18,
	0x18,
	0x18
};

static const u8  rom8x8__0xd6[] ={
		/* Code 0xd6, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |  ******|
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0x3f,
	0x36,
	0x36,
	0x36
};

static const u8  rom8x8__0xd7[] ={
		/* Code 0xd7, ht=8, width=8
		 +--------+
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 |********|
		 |  ** ** |
		 |  ** ** |
		 |  ** ** |
		 +--------+ */
	0x36,
	0x36,
	0x36,
	0x36,
	0xff,
	0x36,
	0x36,
	0x36
};

static const u8  rom8x8__0xd8[] ={
		/* Code 0xd8, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |********|
		 |   **   |
		 |********|
		 |   **   |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x18,
	0x18,
	0xff,
	0x18,
	0xff,
	0x18,
	0x18,
	0x18
};

static const u8  rom8x8__0xd9[] ={
		/* Code 0xd9, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |*****   |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x18,
	0x18,
	0x18,
	0x18,
	0xf8,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xda[] ={
		/* Code 0xda, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |   *****|
		 |   **   |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0x1f,
	0x18,
	0x18,
	0x18
};

static const u8  rom8x8__0xdb[] ={
		/* Code 0xdb, ht=8, width=8
		 +--------+
		 |********|
		 |********|
		 |********|
		 |********|
		 |********|
		 |********|
		 |********|
		 |********|
		 +--------+ */
	0xff,
	0xff,
	0xff,
	0xff,
	0xff,
	0xff,
	0xff,
	0xff
};

static const u8  rom8x8__0xdc[] ={
		/* Code 0xdc, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |********|
		 |********|
		 |********|
		 |********|
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0xff,
	0xff,
	0xff,
	0xff
};

static const u8  rom8x8__0xdd[] ={
		/* Code 0xdd, ht=8, width=8
		 +--------+
		 |****    |
		 |****    |
		 |****    |
		 |****    |
		 |****    |
		 |****    |
		 |****    |
		 |****    |
		 +--------+ */
	0xf0,
	0xf0,
	0xf0,
	0xf0,
	0xf0,
	0xf0,
	0xf0,
	0xf0
};

static const u8  rom8x8__0xde[] ={
		/* Code 0xde, ht=8, width=8
		 +--------+
		 |    ****|
		 |    ****|
		 |    ****|
		 |    ****|
		 |    ****|
		 |    ****|
		 |    ****|
		 |    ****|
		 +--------+ */
	0x0f,
	0x0f,
	0x0f,
	0x0f,
	0x0f,
	0x0f,
	0x0f,
	0x0f
};

static const u8  rom8x8__0xdf[] ={
		/* Code 0xdf, ht=8, width=8
		 +--------+
		 |********|
		 |********|
		 |********|
		 |********|
		 |        |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0xff,
	0xff,
	0xff,
	0xff,
	0x00,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xe0[] ={
		/* Code 0xe0, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 | **  ** |
		 |** ***  |
		 |** **   |
		 |** ***  |
		 | **  ** |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x66,
	0xdc,
	0xd8,
	0xdc,
	0x66,
	0x00
};

static const u8  rom8x8__0xe1[] ={
		/* Code 0xe1, ht=8, width=8
		 +--------+
		 |        |
		 | ****   |
		 |**  **  |
		 |*****   |
		 |**  **  |
		 |**   ** |
		 |**  **  |
		 |        |
		 +--------+ */
	0x00,
	0x78,
	0xcc,
	0xf8,
	0xcc,
	0xc6,
	0xcc,
	0x00
};

static const u8  rom8x8__0xe2[] ={
		/* Code 0xe2, ht=8, width=8
		 +--------+
		 |        |
		 |******* |
		 | **   * |
		 | **     |
		 | **     |
		 | **     |
		 |***     |
		 |        |
		 +--------+ */
	0x00,
	0xfe,
	0x62,
	0x60,
	0x60,
	0x60,
	0xe0,
	0x00
};

static const u8  rom8x8__0xe3[] ={
		/* Code 0xe3, ht=8, width=8
		 +--------+
		 |        |
		 |******* |
		 | ** **  |
		 | ** **  |
		 | ** **  |
		 | ** **  |
		 | ** **  |
		 |        |
		 +--------+ */
	0x00,
	0xfe,
	0x6c,
	0x6c,
	0x6c,
	0x6c,
	0x6c,
	0x00
};

static const u8  rom8x8__0xe4[] ={
		/* Code 0xe4, ht=8, width=8
		 +--------+
		 |******* |
		 |**   ** |
		 | **     |
		 |  **    |
		 | **     |
		 |**   ** |
		 |******* |
		 |        |
		 +--------+ */
	0xfe,
	0xc6,
	0x60,
	0x30,
	0x60,
	0xc6,
	0xfe,
	0x00
};

static const u8  rom8x8__0xe5[] ={
		/* Code 0xe5, ht=8, width=8
		 +--------+
		 |        |
		 | ****** |
		 |** **   |
		 |**  **  |
		 |**  **  |
		 |** **   |
		 | ***    |
		 |        |
		 +--------+ */
	0x00,
	0x7e,
	0xd8,
	0xcc,
	0xcc,
	0xd8,
	0x70,
	0x00
};

static const u8  rom8x8__0xe6[] ={
		/* Code 0xe6, ht=8, width=8
		 +--------+
		 |        |
		 | **  ** |
		 | **  ** |
		 | **  ** |
		 | **  ** |
		 | *****  |
		 |**      |
		 |        |
		 +--------+ */
	0x00,
	0x66,
	0x66,
	0x66,
	0x66,
	0x7c,
	0xc0,
	0x00
};

static const u8  rom8x8__0xe7[] ={
		/* Code 0xe7, ht=8, width=8
		 +--------+
		 |        |
		 | *** ** |
		 |** ***  |
		 |   **   |
		 |   **   |
		 |   **   |
		 |  ***   |
		 |        |
		 +--------+ */
	0x00,
	0x76,
	0xdc,
	0x18,
	0x18,
	0x18,
	0x38,
	0x00
};

static const u8  rom8x8__0xe8[] ={
		/* Code 0xe8, ht=8, width=8
		 +--------+
		 |******* |
		 |  ***   |
		 | ** **  |
		 |**   ** |
		 | ** **  |
		 |  ***   |
		 |******* |
		 |        |
		 +--------+ */
	0xfe,
	0x38,
	0x6c,
	0xc6,
	0x6c,
	0x38,
	0xfe,
	0x00
};

static const u8  rom8x8__0xe9[] ={
		/* Code 0xe9, ht=8, width=8
		 +--------+
		 |  ***   |
		 | ** **  |
		 |**   ** |
		 |******* |
		 |**   ** |
		 | ** **  |
		 |  ***   |
		 |        |
		 +--------+ */
	0x38,
	0x6c,
	0xc6,
	0xfe,
	0xc6,
	0x6c,
	0x38,
	0x00
};

static const u8  rom8x8__0xea[] ={
		/* Code 0xea, ht=8, width=8
		 +--------+
		 |  ***   |
		 | ** **  |
		 |**   ** |
		 |**   ** |
		 | ** **  |
		 | ** **  |
		 |*** *** |
		 |        |
		 +--------+ */
	0x38,
	0x6c,
	0xc6,
	0xc6,
	0x6c,
	0x6c,
	0xee,
	0x00
};

static const u8  rom8x8__0xeb[] ={
		/* Code 0xeb, ht=8, width=8
		 +--------+
		 |  ***** |
		 | **     |
		 |  ***   |
		 | **  ** |
		 |**   ** |
		 |**  **  |
		 | ****   |
		 |        |
		 +--------+ */
	0x3e,
	0x60,
	0x38,
	0x66,
	0xc6,
	0xcc,
	0x78,
	0x00
};

static const u8  rom8x8__0xec[] ={
		/* Code 0xec, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 | ****** |
		 |** ** **|
		 |** ** **|
		 | ****** |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x7e,
	0xdb,
	0xdb,
	0x7e,
	0x00,
	0x00
};

static const u8  rom8x8__0xed[] ={
		/* Code 0xed, ht=8, width=8
		 +--------+
		 |     ** |
		 | *****  |
		 |** **** |
		 |**** ** |
		 |***  ** |
		 | *****  |
		 |**      |
		 |        |
		 +--------+ */
	0x06,
	0x7c,
	0xde,
	0xf6,
	0xe6,
	0x7c,
	0xc0,
	0x00
};

static const u8  rom8x8__0xee[] ={
		/* Code 0xee, ht=8, width=8
		 +--------+
		 |  ***   |
		 | **     |
		 |**      |
		 |*****   |
		 |**      |
		 | **     |
		 |  ***   |
		 |        |
		 +--------+ */
	0x38,
	0x60,
	0xc0,
	0xf8,
	0xc0,
	0x60,
	0x38,
	0x00
};

static const u8  rom8x8__0xef[] ={
		/* Code 0xef, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |**   ** |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0xc6,
	0xc6,
	0xc6,
	0xc6,
	0xc6,
	0x00
};

static const u8  rom8x8__0xf0[] ={
		/* Code 0xf0, ht=8, width=8
		 +--------+
		 |        |
		 |******* |
		 |        |
		 |******* |
		 |        |
		 |******* |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0xfe,
	0x00,
	0xfe,
	0x00,
	0xfe,
	0x00,
	0x00
};

static const u8  rom8x8__0xf1[] ={
		/* Code 0xf1, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 | ****** |
		 |   **   |
		 |   **   |
		 |        |
		 | ****** |
		 |        |
		 +--------+ */
	0x18,
	0x18,
	0x7e,
	0x18,
	0x18,
	0x00,
	0x7e,
	0x00
};

static const u8  rom8x8__0xf2[] ={
		/* Code 0xf2, ht=8, width=8
		 +--------+
		 |  **    |
		 |   **   |
		 |    **  |
		 |   **   |
		 |  **    |
		 |        |
		 | ****** |
		 |        |
		 +--------+ */
	0x30,
	0x18,
	0x0c,
	0x18,
	0x30,
	0x00,
	0x7e,
	0x00
};

static const u8  rom8x8__0xf3[] ={
		/* Code 0xf3, ht=8, width=8
		 +--------+
		 |    **  |
		 |   **   |
		 |  **    |
		 |   **   |
		 |    **  |
		 |        |
		 | ****** |
		 |        |
		 +--------+ */
	0x0c,
	0x18,
	0x30,
	0x18,
	0x0c,
	0x00,
	0x7e,
	0x00
};

static const u8  rom8x8__0xf4[] ={
		/* Code 0xf4, ht=8, width=8
		 +--------+
		 |    **  |
		 |   **** |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 +--------+ */
	0x0c,
	0x1e,
	0x18,
	0x18,
	0x18,
	0x18,
	0x18,
	0x18
};

static const u8  rom8x8__0xf5[] ={
		/* Code 0xf5, ht=8, width=8
		 +--------+
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 |   **   |
		 | ****   |
		 |  **    |
		 |        |
		 +--------+ */
	0x18,
	0x18,
	0x18,
	0x18,
	0x18,
	0x78,
	0x30,
	0x00
};

static const u8  rom8x8__0xf6[] ={
		/* Code 0xf6, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |   **   |
		 |        |
		 | ****** |
		 |        |
		 |   **   |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x18,
	0x00,
	0x7e,
	0x00,
	0x18,
	0x00
};

static const u8  rom8x8__0xf7[] ={
		/* Code 0xf7, ht=8, width=8
		 +--------+
		 |        |
		 | *** ** |
		 |** ***  |
		 |        |
		 | *** ** |
		 |** ***  |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x76,
	0xdc,
	0x00,
	0x76,
	0xdc,
	0x00,
	0x00
};

static const u8  rom8x8__0xf8[] ={
		/* Code 0xf8, ht=8, width=8
		 +--------+
		 | *****  |
		 |**   ** |
		 |**   ** |
		 | *****  |
		 |        |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x7c,
	0xc6,
	0xc6,
	0x7c,
	0x00,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xf9[] ={
		/* Code 0xf9, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |   **   |
		 |   **   |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x18,
	0x18,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xfa[] ={
		/* Code 0xfa, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |   **   |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0x18,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xfb[] ={
		/* Code 0xfb, ht=8, width=8
		 +--------+
		 |   *****|
		 |   **   |
		 |   **   |
		 |   **   |
		 |*****   |
		 |  ***   |
		 |   **   |
		 |        |
		 +--------+ */
	0x1f,
	0x18,
	0x18,
	0x18,
	0xf8,
	0x38,
	0x18,
	0x00
};

static const u8  rom8x8__0xfc[] ={
		/* Code 0xfc, ht=8, width=8
		 +--------+
		 |** **   |
		 | ** **  |
		 | ** **  |
		 | ** **  |
		 |        |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0xd8,
	0x6c,
	0x6c,
	0x6c,
	0x00,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xfd[] ={
		/* Code 0xfd, ht=8, width=8
		 +--------+
		 | ***    |
		 |** **   |
		 |  **    |
		 |*****   |
		 |        |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x70,
	0xd8,
	0x30,
	0xf8,
	0x00,
	0x00,
	0x00,
	0x00
};

static const u8  rom8x8__0xfe[] ={
		/* Code 0xfe, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 | *****  |
		 | *****  |
		 | *****  |
		 | *****  |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x7c,
	0x7c,
	0x7c,
	0x7c,
	0x00,
	0x00
};

static const u8  rom8x8__0xff[] ={
		/* Code 0xff, ht=8, width=8
		 +--------+
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 |        |
		 +--------+ */
	0x00,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00,
	0x00
};
#endif /* EXTENDED_ASCII */

static const struct fontimg_t	rom8x8_lut[] = {
#ifdef EXTENDED_ASCII
	{8, rom8x8__0x00},	/* Character (0x00) */
	{8, rom8x8__0x01},	/* Character (0x01) */
	{8, rom8x8__0x02},	/* Character (0x02) */
	{8, rom8x8__0x03},	/* Character (0x03) */
	{8, rom8x8__0x04},	/* Character (0x04) */
	{8, rom8x8__0x05},	/* Character (0x05) */
	{8, rom8x8__0x06},	/* Character (0x06) */
	{8, rom8x8__0x07},	/* Character (0x07) */
	{8, rom8x8__0x08},	/* Character (0x08) */
	{8, rom8x8__0x09},	/* Character (0x09) */
	{8, rom8x8__0x0a},	/* Character (0x0a) */
	{8, rom8x8__0x0b},	/* Character (0x0b) */
	{8, rom8x8__0x0c},	/* Character (0x0c) */
	{8, rom8x8__0x0d},	/* Character (0x0d) */
	{8, rom8x8__0x0e},	/* Character (0x0e) */
	{8, rom8x8__0x0f},	/* Character (0x0f) */
	{8, rom8x8__0x10},	/* Character (0x10) */
	{8, rom8x8__0x11},	/* Character (0x11) */
	{8, rom8x8__0x12},	/* Character (0x12) */
	{8, rom8x8__0x13},	/* Character (0x13) */
	{8, rom8x8__0x14},	/* Character (0x14) */
	{8, rom8x8__0x15},	/* Character (0x15) */
	{8, rom8x8__0x16},	/* Character (0x16) */
	{8, rom8x8__0x17},	/* Character (0x17) */
	{8, rom8x8__0x18},	/* Character (0x18) */
	{8, rom8x8__0x19},	/* Character (0x19) */
	{8, rom8x8__0x1a},	/* Character (0x1a) */
	{8, rom8x8__0x1b},	/* Character (0x1b) */
	{8, rom8x8__0x1c},	/* Character (0x1c) */
	{8, rom8x8__0x1d},	/* Character (0x1d) */
	{8, rom8x8__0x1e},	/* Character (0x1e) */
	{8, rom8x8__0x1f},	/* Character (0x1f) */
#endif /* EXTENDED_ASCII */
	{8, rom8x8__0x20},	/* Character (0x20) */
	{8, rom8x8__0x21},	/* Character (0x21) */
	{8, rom8x8__0x22},	/* Character (0x22) */
	{8, rom8x8__0x23},	/* Character (0x23) */
	{8, rom8x8__0x24},	/* Character (0x24) */
	{8, rom8x8__0x25},	/* Character (0x25) */
	{8, rom8x8__0x26},	/* Character (0x26) */
	{8, rom8x8__0x27},	/* Character (0x27) */
	{8, rom8x8__0x28},	/* Character (0x28) */
	{8, rom8x8__0x29},	/* Character (0x29) */
	{8, rom8x8__0x2a},	/* Character (0x2a) */
	{8, rom8x8__0x2b},	/* Character (0x2b) */
	{8, rom8x8__0x2c},	/* Character (0x2c) */
	{8, rom8x8__0x2d},	/* Character (0x2d) */
	{8, rom8x8__0x2e},	/* Character (0x2e) */
	{8, rom8x8__0x2f},	/* Character (0x2f) */
	{8, rom8x8__0x30},	/* Character (0x30) */
	{8, rom8x8__0x31},	/* Character (0x31) */
	{8, rom8x8__0x32},	/* Character (0x32) */
	{8, rom8x8__0x33},	/* Character (0x33) */
	{8, rom8x8__0x34},	/* Character (0x34) */
	{8, rom8x8__0x35},	/* Character (0x35) */
	{8, rom8x8__0x36},	/* Character (0x36) */
	{8, rom8x8__0x37},	/* Character (0x37) */
	{8, rom8x8__0x38},	/* Character (0x38) */
	{8, rom8x8__0x39},	/* Character (0x39) */
	{8, rom8x8__0x3a},	/* Character (0x3a) */
	{8, rom8x8__0x3b},	/* Character (0x3b) */
	{8, rom8x8__0x3c},	/* Character (0x3c) */
	{8, rom8x8__0x3d},	/* Character (0x3d) */
	{8, rom8x8__0x3e},	/* Character (0x3e) */
	{8, rom8x8__0x3f},	/* Character (0x3f) */
	{8, rom8x8__0x40},	/* Character (0x40) */
	{8, rom8x8__0x41},	/* Character (0x41) */
	{8, rom8x8__0x42},	/* Character (0x42) */
	{8, rom8x8__0x43},	/* Character (0x43) */
	{8, rom8x8__0x44},	/* Character (0x44) */
	{8, rom8x8__0x45},	/* Character (0x45) */
	{8, rom8x8__0x46},	/* Character (0x46) */
	{8, rom8x8__0x47},	/* Character (0x47) */
	{8, rom8x8__0x48},	/* Character (0x48) */
	{8, rom8x8__0x49},	/* Character (0x49) */
	{8, rom8x8__0x4a},	/* Character (0x4a) */
	{8, rom8x8__0x4b},	/* Character (0x4b) */
	{8, rom8x8__0x4c},	/* Character (0x4c) */
	{8, rom8x8__0x4d},	/* Character (0x4d) */
	{8, rom8x8__0x4e},	/* Character (0x4e) */
	{8, rom8x8__0x4f},	/* Character (0x4f) */
	{8, rom8x8__0x50},	/* Character (0x50) */
	{8, rom8x8__0x51},	/* Character (0x51) */
	{8, rom8x8__0x52},	/* Character (0x52) */
	{8, rom8x8__0x53},	/* Character (0x53) */
	{8, rom8x8__0x54},	/* Character (0x54) */
	{8, rom8x8__0x55},	/* Character (0x55) */
	{8, rom8x8__0x56},	/* Character (0x56) */
	{8, rom8x8__0x57},	/* Character (0x57) */
	{8, rom8x8__0x58},	/* Character (0x58) */
	{8, rom8x8__0x59},	/* Character (0x59) */
	{8, rom8x8__0x5a},	/* Character (0x5a) */
	{8, rom8x8__0x5b},	/* Character (0x5b) */
	{8, rom8x8__0x5c},	/* Character (0x5c) */
	{8, rom8x8__0x5d},	/* Character (0x5d) */
	{8, rom8x8__0x5e},	/* Character (0x5e) */
	{8, rom8x8__0x5f},	/* Character (0x5f) */
	{8, rom8x8__0x60},	/* Character (0x60) */
	{8, rom8x8__0x61},	/* Character (0x61) */
	{8, rom8x8__0x62},	/* Character (0x62) */
	{8, rom8x8__0x63},	/* Character (0x63) */
	{8, rom8x8__0x64},	/* Character (0x64) */
	{8, rom8x8__0x65},	/* Character (0x65) */
	{8, rom8x8__0x66},	/* Character (0x66) */
	{8, rom8x8__0x67},	/* Character (0x67) */
	{8, rom8x8__0x68},	/* Character (0x68) */
	{8, rom8x8__0x69},	/* Character (0x69) */
	{8, rom8x8__0x6a},	/* Character (0x6a) */
	{8, rom8x8__0x6b},	/* Character (0x6b) */
	{8, rom8x8__0x6c},	/* Character (0x6c) */
	{8, rom8x8__0x6d},	/* Character (0x6d) */
	{8, rom8x8__0x6e},	/* Character (0x6e) */
	{8, rom8x8__0x6f},	/* Character (0x6f) */
	{8, rom8x8__0x70},	/* Character (0x70) */
	{8, rom8x8__0x71},	/* Character (0x71) */
	{8, rom8x8__0x72},	/* Character (0x72) */
	{8, rom8x8__0x73},	/* Character (0x73) */
	{8, rom8x8__0x74},	/* Character (0x74) */
	{8, rom8x8__0x75},	/* Character (0x75) */
	{8, rom8x8__0x76},	/* Character (0x76) */
	{8, rom8x8__0x77},	/* Character (0x77) */
	{8, rom8x8__0x78},	/* Character (0x78) */
	{8, rom8x8__0x79},	/* Character (0x79) */
	{8, rom8x8__0x7a},	/* Character (0x7a) */
	{8, rom8x8__0x7b},	/* Character (0x7b) */
	{8, rom8x8__0x7c},	/* Character (0x7c) */
	{8, rom8x8__0x7d},	/* Character (0x7d) */
	{8, rom8x8__0x7e},	/* Character (0x7e) */
	{8, rom8x8__0x7f},	/* Character (0x7f) */
#ifdef EXTENDED_ASCII
	{8, rom8x8__0x80},	/* Character (0x80) */
	{8, rom8x8__0x81},	/* Character (0x81) */
	{8, rom8x8__0x82},	/* Character (0x82) */
	{8, rom8x8__0x83},	/* Character (0x83) */
	{8, rom8x8__0x84},	/* Character (0x84) */
	{8, rom8x8__0x85},	/* Character (0x85) */
	{8, rom8x8__0x86},	/* Character (0x86) */
	{8, rom8x8__0x87},	/* Character (0x87) */
	{8, rom8x8__0x88},	/* Character (0x88) */
	{8, rom8x8__0x89},	/* Character (0x89) */
	{8, rom8x8__0x8a},	/* Character (0x8a) */
	{8, rom8x8__0x8b},	/* Character (0x8b) */
	{8, rom8x8__0x8c},	/* Character (0x8c) */
	{8, rom8x8__0x8d},	/* Character (0x8d) */
	{8, rom8x8__0x8e},	/* Character (0x8e) */
	{8, rom8x8__0x8f},	/* Character (0x8f) */
	{8, rom8x8__0x90},	/* Character (0x90) */
	{8, rom8x8__0x91},	/* Character (0x91) */
	{8, rom8x8__0x92},	/* Character (0x92) */
	{8, rom8x8__0x93},	/* Character (0x93) */
	{8, rom8x8__0x94},	/* Character (0x94) */
	{8, rom8x8__0x95},	/* Character (0x95) */
	{8, rom8x8__0x96},	/* Character (0x96) */
	{8, rom8x8__0x97},	/* Character (0x97) */
	{8, rom8x8__0x98},	/* Character (0x98) */
	{8, rom8x8__0x99},	/* Character (0x99) */
	{8, rom8x8__0x9a},	/* Character (0x9a) */
	{8, rom8x8__0x9b},	/* Character (0x9b) */
	{8, rom8x8__0x9c},	/* Character (0x9c) */
	{8, rom8x8__0x9d},	/* Character (0x9d) */
	{8, rom8x8__0x9e},	/* Character (0x9e) */
	{8, rom8x8__0x9f},	/* Character (0x9f) */
	{8, rom8x8__0xa0},	/* Character (0xa0) */
	{8, rom8x8__0xa1},	/* Character (0xa1) */
	{8, rom8x8__0xa2},	/* Character (0xa2) */
	{8, rom8x8__0xa3},	/* Character (0xa3) */
	{8, rom8x8__0xa4},	/* Character (0xa4) */
	{8, rom8x8__0xa5},	/* Character (0xa5) */
	{8, rom8x8__0xa6},	/* Character (0xa6) */
	{8, rom8x8__0xa7},	/* Character (0xa7) */
	{8, rom8x8__0xa8},	/* Character (0xa8) */
	{8, rom8x8__0xa9},	/* Character (0xa9) */
	{8, rom8x8__0xaa},	/* Character (0xaa) */
	{8, rom8x8__0xab},	/* Character (0xab) */
	{8, rom8x8__0xac},	/* Character (0xac) */
	{8, rom8x8__0xad},	/* Character (0xad) */
	{8, rom8x8__0xae},	/* Character (0xae) */
	{8, rom8x8__0xaf},	/* Character (0xaf) */
	{8, rom8x8__0xb0},	/* Character (0xb0) */
	{8, rom8x8__0xb1},	/* Character (0xb1) */
	{8, rom8x8__0xb2},	/* Character (0xb2) */
	{8, rom8x8__0xb3},	/* Character (0xb3) */
	{8, rom8x8__0xb4},	/* Character (0xb4) */
	{8, rom8x8__0xb5},	/* Character (0xb5) */
	{8, rom8x8__0xb6},	/* Character (0xb6) */
	{8, rom8x8__0xb7},	/* Character (0xb7) */
	{8, rom8x8__0xb8},	/* Character (0xb8) */
	{8, rom8x8__0xb9},	/* Character (0xb9) */
	{8, rom8x8__0xba},	/* Character (0xba) */
	{8, rom8x8__0xbb},	/* Character (0xbb) */
	{8, rom8x8__0xbc},	/* Character (0xbc) */
	{8, rom8x8__0xbd},	/* Character (0xbd) */
	{8, rom8x8__0xbe},	/* Character (0xbe) */
	{8, rom8x8__0xbf},	/* Character (0xbf) */
	{8, rom8x8__0xc0},	/* Character (0xc0) */
	{8, rom8x8__0xc1},	/* Character (0xc1) */
	{8, rom8x8__0xc2},	/* Character (0xc2) */
	{8, rom8x8__0xc3},	/* Character (0xc3) */
	{8, rom8x8__0xc4},	/* Character (0xc4) */
	{8, rom8x8__0xc5},	/* Character (0xc5) */
	{8, rom8x8__0xc6},	/* Character (0xc6) */
	{8, rom8x8__0xc7},	/* Character (0xc7) */
	{8, rom8x8__0xc8},	/* Character (0xc8) */
	{8, rom8x8__0xc9},	/* Character (0xc9) */
	{8, rom8x8__0xca},	/* Character (0xca) */
	{8, rom8x8__0xcb},	/* Character (0xcb) */
	{8, rom8x8__0xcc},	/* Character (0xcc) */
	{8, rom8x8__0xcd},	/* Character (0xcd) */
	{8, rom8x8__0xce},	/* Character (0xce) */
	{8, rom8x8__0xcf},	/* Character (0xcf) */
	{8, rom8x8__0xd0},	/* Character (0xd0) */
	{8, rom8x8__0xd1},	/* Character (0xd1) */
	{8, rom8x8__0xd2},	/* Character (0xd2) */
	{8, rom8x8__0xd3},	/* Character (0xd3) */
	{8, rom8x8__0xd4},	/* Character (0xd4) */
	{8, rom8x8__0xd5},	/* Character (0xd5) */
	{8, rom8x8__0xd6},	/* Character (0xd6) */
	{8, rom8x8__0xd7},	/* Character (0xd7) */
	{8, rom8x8__0xd8},	/* Character (0xd8) */
	{8, rom8x8__0xd9},	/* Character (0xd9) */
	{8, rom8x8__0xda},	/* Character (0xda) */
	{8, rom8x8__0xdb},	/* Character (0xdb) */
	{8, rom8x8__0xdc},	/* Character (0xdc) */
	{8, rom8x8__0xdd},	/* Character (0xdd) */
	{8, rom8x8__0xde},	/* Character (0xde) */
	{8, rom8x8__0xdf},	/* Character (0xdf) */
	{8, rom8x8__0xe0},	/* Character (0xe0) */
	{8, rom8x8__0xe1},	/* Character (0xe1) */
	{8, rom8x8__0xe2},	/* Character (0xe2) */
	{8, rom8x8__0xe3},	/* Character (0xe3) */
	{8, rom8x8__0xe4},	/* Character (0xe4) */
	{8, rom8x8__0xe5},	/* Character (0xe5) */
	{8, rom8x8__0xe6},	/* Character (0xe6) */
	{8, rom8x8__0xe7},	/* Character (0xe7) */
	{8, rom8x8__0xe8},	/* Character (0xe8) */
	{8, rom8x8__0xe9},	/* Character (0xe9) */
	{8, rom8x8__0xea},	/* Character (0xea) */
	{8, rom8x8__0xeb},	/* Character (0xeb) */
	{8, rom8x8__0xec},	/* Character (0xec) */
	{8, rom8x8__0xed},	/* Character (0xed) */
	{8, rom8x8__0xee},	/* Character (0xee) */
	{8, rom8x8__0xef},	/* Character (0xef) */
	{8, rom8x8__0xf0},	/* Character (0xf0) */
	{8, rom8x8__0xf1},	/* Character (0xf1) */
	{8, rom8x8__0xf2},	/* Character (0xf2) */
	{8, rom8x8__0xf3},	/* Character (0xf3) */
	{8, rom8x8__0xf4},	/* Character (0xf4) */
	{8, rom8x8__0xf5},	/* Character (0xf5) */
	{8, rom8x8__0xf6},	/* Character (0xf6) */
	{8, rom8x8__0xf7},	/* Character (0xf7) */
	{8, rom8x8__0xf8},	/* Character (0xf8) */
	{8, rom8x8__0xf9},	/* Character (0xf9) */
	{8, rom8x8__0xfa},	/* Character (0xfa) */
	{8, rom8x8__0xfb},	/* Character (0xfb) */
	{8, rom8x8__0xfc},	/* Character (0xfc) */
	{8, rom8x8__0xfd},	/* Character (0xfd) */
	{8, rom8x8__0xfe},	/* Character (0xfe) */
	{8, rom8x8__0xff}	/* Character (0xff) */
#endif /* EXTENDED_ASCII */
};

/* Font information structure */
const struct font_t	font_rom8x8 = {
	.height      = ARRAY_SIZE(rom8x8__0x41),
	.bitmapwidth = sizeof(rom8x8__0x41[0]),
#ifdef EXTENDED_ASCII
	.offset      = 0x00,
#else
	.offset      = 0x20,
#endif /* EXTENDED_ASCII */
	.size        = ARRAY_SIZE(rom8x8_lut),
	.image_lut   = rom8x8_lut
};
