/*
 * Copyright (C) 2020 Hottinger Bruel & Kjaer Benelux B.V.
 * Schutweg 15a
 * 5145 NP Waalwijk
 * The Netherlands
 * http://www.hbm.com
 * All rights reserved
 *
 * The copyright to the computer program(s) herein is the property of
 * Hottinger Bruel & Kjaer Benelux B.V., Netherlands. The code/program(s)
 * may be used and/or copied only with the written permission of 
 * Hottinger Bruel & Kjaer Benelux B.V. or in accordance with the terms 
 * and conditions stipulated in the agreement/contract under which the 
 * program(s) have been supplied.
 * This copyright notice must not be removed.
 *
 * This Source Code is subject to the
 * "General supply and license conditions for software"
 * which is part of the standard terms and conditions of sale from 
 * Hottinger Bruel & Kjaer Benelux B.V..
 */

/*
 * Copyright (C) 2011-2017 HBM Netherlands B.V.
 * Schutweg 15a
 * 5145NP Waalwijk
 * The Netherlands
 * http://www.hbm.com
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*
 * This file contains the internal interface between hbm-fpga-* files.
 * Do NOT include this header anywhere else but this driver.
 */

#ifndef HBM_FPGA_CORE_H
#define HBM_FPGA_CORE_H


#define MINORS				256
#define INSTANCES			(MINORS / DEV_NODES)	/* Number or driver instances supported */

#define FPGA_DEV_NODE_OFFSET            0			/* FPGA character device minor number offset to instance number */
#define LCD_DEV_NODE_OFFSET             1			/* LCD character device minor number offset to instance number */
#define DEV_NODES                       2			/* Number of character device nodes per driver instance (must be a power of 2) */


/*
 * FPGA instance data
 */
struct hbm_fpga_dev {
	int                             instance_nr;            /* Instance number, doubles as minor number base for character devices and used to post-fix devnodes */

	struct pci_dev                  *pci_dev;
	u32				subdevice;		/* PCI subdevice ID */

	struct variant_t                *variant;               /* Instance variant reference */
	struct i2c_t                    *i2c;                   /* I2C instance reference */
	struct lcd_t                    *lcd;                   /* LCD instance reference */
	struct button_t                 *button;                /* Button instance reference */

	struct kfifo                    *event_queue;
	spinlock_t                      event_queue_spinlock;   /* Protects both event_queue and *event_queue */
	wait_queue_head_t               wait_queue;             /* Used to signal read() when data is available */

	/* Interrupt resources */
	u8                              irq;                    /* Interrupt request source number */
	spinlock_t                      irq_spinlock;
	unsigned int                    irq_mask;

	/* Memory resources */
	unsigned long                   fpga_mem_base;          /* Physical memory base address */
	size_t                          fpga_mem_size;          /* Memory size */
	volatile struct hbm_fpga_regs   *regs;                  /* Virtual memory base address */

	struct mutex                    driver_mutex;

	/* FPGA character device */
	dev_t                           fpga_dev;
	struct cdev                     fpga_cdev;

	unsigned int                    trace_flags;
};


void hbm_fpga_change_irq_mask(struct hbm_fpga_dev  *fpga,
                              unsigned int         enable_mask,
                              unsigned int         disable_mask);

void hbm_fpga_queue_event    (struct hbm_fpga_dev  *fpga,
                              irq_event            *event);

#endif /* HBM_FPGA_CORE_H */
