const port = process.env.PORT || 8000

const logger = require('./createLogger.js')()
const database_data = require('./database/createDatabase.js')
const database_settings = require('./database/createDatabaseSettings.js')
const app = require('./createHMIApp.js')
const server = require('http').createServer()

start = async () => {
    
    let db_settings = await database_settings.initializeSettingsDB(logger, require('./database/sqlite-async'))
    let db_data = await database_data.initializeDataDB(logger, require('./database/sqlite-async'))
    let hmiApp = await app.initializeApp(logger, db_data, db_settings)

    server
    .on('request', hmiApp)
    .on('listening', function() {
        const addr = this.address()
        const bind = typeof addr === 'string' ? `pipe ${addr}` : `port ${addr.port}`
        logger.info(`Listening on ${bind}`)
    })
    .on('error', function(error) {
        if (error.syscall !== 'listen') throw error
        const addr = this.address() || { port }
        const bind = typeof addr === 'string' ? `pipe ${addr}` : `port ${addr.port}`
        switch (error.code) {
        case 'EACCES':
            logger.error(`${bind} requires elevated privileges`)
            return process.exit(1)
        case 'EADDRINUSE':
            logger.error(`${bind} is already in use`)
            return process.exit(1)
        default:
            throw error
        }
    })
    .listen(port)
}

start();

module.exports = app
