const express = require('express')
const bodyParser = require('body-parser')
const expressWinston = require('express-winston')
const fileUpload = require('express-fileupload');
const apiRouter = require('./rest/createRestRouter.js')()
const pagesRouter = require('./pages/createPagesRouter.js')()
const dev = require('./misc/device.js')()
const upgradeRouter = require('./pages/createUpgradeRouter.js')()
const websocket = require('./websocket/websocket.js')

const gendaqCtrl = require('./gendaq/gendaq');
const GenDaqDataDispatcher = require('./gendaq/gendaq').GenDaqDataDispatcher;
const genDaqDataDispatcher = new GenDaqDataDispatcher();

let db_settings = null
//gendaq stuff

//dashboard data
let dashboard_data = {}
global.dashboard_data = dashboard_data

module.exports = {
    initializeApp: async (logger, database_data, database_settings) => {  
             
        //Initialization stuff
        db_settings = database_settings
        genDaqDataDispatcher.setInstance(genDaqDataDispatcher, database_data);
        websocket.initWebSocket(logger)
        dev.initializeDeviceInformation(database_data, logger)

        //Get app version from system
        let hmiVersion = await dev.getAppSwVersion()
        logger.info("Starting HBM GenesisHighSpeed HMI, version " + hmiVersion)

        //Express application
        return express()
        .use(expressWinston.logger({
            winstonInstance: logger,
            msg: '{{res.statusCode}} {{req.method}} {{req.url}} {{res.responseTime}}ms',
            meta: false,
        }))
        .use(fileUpload({
            createParentPath: true,
            debug: false
        }))
        .use(bodyParser.urlencoded({ extended: true }))
        .use(bodyParser.json())
        .use((req, res, next) => {
            req.base = `${req.protocol}://${req.get('host')}`
            req.logger = logger
            req.dbs = database_settings
            req.db = database_data
            req.param.data = dashboard_data
            req.hmiVersion = hmiVersion
            req.dev = dev
            return next()
        }) 
        .set('views', __dirname + '/views/html')
        .set('view engine', 'ejs')
        .use('/', ( hmiVersion !== "0.1.0" && hmiVersion !== "x.x.x" ) ? pagesRouter : upgradeRouter)
        .use('/rest', ( hmiVersion !== "0.1.0" && hmiVersion !== "x.x.x" ) ? apiRouter : upgradeRouter)
        .use((req, res) => {
            res.status(404)
                .render('error-404', { data: { url: "error-404" } });
        })
    }
}

genDaqDataDispatcher.on('connect-error', function(){
    websocket.sendWebSocketMsg("connect-error")
})

async function main() {
    if(db_settings == null){
        setTimeout(main, 2000)
        return
    }

    let demo_mode = await db_settings.settings.getDemoMode()
    var status = gendaqCtrl.getStatus()

    switch (status) {
        case "disconnected":
            if (demo_mode == 'false' && websocket.areClientsConnected() > 0) {
                gendaqCtrl.start()
                websocket.sendWebSocketMsg(status)
            }
            break;
        case "connect-error":
                websocket.sendWebSocketMsg("connect-error")
                gendaqCtrl.stop()
            break;
        default:
            if (demo_mode == 'true' || websocket.areClientsConnected() <= 0) {
                gendaqCtrl.stop()
            }
            websocket.sendWebSocketMsg(status)
    }
    setTimeout(main, 2000)
}

//trigger main for gendaq connection control
main()