const glob = require('glob')
const path = require('path')
const confs = require('../confs/config.conf')
const dbPath = process.env.DB_SETTINGS_PATH || '/mnt/settings/hmi_settings.sqlite'

module.exports = {
    initializeSettingsDB: async (logger, sqlite3) => {
        let db_sqlite = await sqlite3.open(dbPath, sqlite3.OPEN_READWRITE | sqlite3.OPEN_CREATE)
        .catch(err => {
            logger.error(err.message);
        });
        logger.info('Connected to the hmi_settings database.');
        await db_sqlite.run('CREATE TABLE IF NOT EXISTS settings (id INTEGER PRIMARY KEY AUTOINCREMENT, setting_name TEXT, setting_value TEXT)')

        for ( const element of confs.settings) {
            let sql = `SELECT * FROM settings
                WHERE setting_name  = ?`;

            // first row only
            let rslt = await db_sqlite.get(sql, [element.name])
            if(rslt == null){
                sql = `INSERT INTO settings(setting_name, setting_value) VALUES(?,?)`;
                await db_sqlite.run(sql, [element.name, element.value])
                logger.info("Added default setting: " + element.name + " with value: " + element.value)
            }
        }
        db_sqlite.settings = require('./models/settings')(db_sqlite);
        return db_sqlite
    }
}

