/* 
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */


const EventEmitter = require('events');

//constants
const api_version = 3;
const json_version = "2.0";

//current service
let gendaqCurrentService = { name: "none", id: 0 };
let jsonStr = "";
var gendaqFuncs = [
  ["default",                           DefaultMethod],
  ["Connect",                           Connect],
  ["Disconnect",                        Disconnect],
  ["InitiateFieldBusDataTransfer",      InitiateFieldBusDataTransfer],
  ["GetFieldBusDataNameAndUnit",        GetFieldBusDataNameAndUnit]
];

function MethodLookup(methodName){
    for(var i = 0; i < gendaqFuncs.length; i++)
        if(gendaqFuncs[i][0] === methodName)
            return i;
    return 0;
}

//GENDAQ JSON helper functions
//Default method
function DefaultMethod(id, methodName, params){    
    var data = {
        jsonrpc: json_version,
        method: methodName,
        id : id
    }

    return JSON.stringify(data);
}

//GenDaq API Initialize
function Connect(id, methodName, params){    
    var json_params = {
        ClientAPIVersion: api_version
    }
    var data = {
        jsonrpc: json_version,
        method: "Connect",
        params: json_params,
        id : id
    }

    return JSON.stringify(data);
}

//GenDaq API End
function Disconnect(id, methodName, params){
    data = {
        jsonrpc: json_version,
        method: "Disconnect",
        id : id
    }
    
    return JSON.stringify(data);
}

//{"jsonrpc":"2.0","method":"InitiateFieldBusDataTransfer","params":{"UpdateRate":2000},"id":2}
function InitiateFieldBusDataTransfer(id, methodName, updateRate){
    var json_params = {
        UpdateRate: updateRate
    }
    var data = {
        jsonrpc: json_version,
        method: "InitiateFieldBusDataTransfer",
        params: json_params,
        id : id
    }
    
    return JSON.stringify(data);
}

function GetFieldBusDataNameAndUnit(id, methodName, dataIndex){
    var json_params = {
        DataIndex: dataIndex
    }
    var data = {
        jsonrpc: json_version,
        method: "GetFieldBusDataNameAndUnit",
        params: json_params,
        id : id
    }
    
    return JSON.stringify(data);
}

//GENDAQ interface class, emit event to send a request
class GenDaqAPI extends EventEmitter {
    getFieldBusDataCount() {
        gendaqCurrentService.name = "GetFieldBusDataCount";
        gendaqCurrentService.id++;
        var methodIndex = MethodLookup(gendaqCurrentService.name);
        jsonStr = gendaqFuncs[methodIndex][1](gendaqCurrentService.id, gendaqCurrentService.name);
        this.emit('gendaq-send', jsonStr);
    }
    
    getFieldBusDataNameAndUnit(dataCount) {
        gendaqCurrentService.name = "GetFieldBusDataNameAndUnit";
        var methodIndex = MethodLookup(gendaqCurrentService.name);
        for (let i = 0; i < dataCount; i++) {
            gendaqCurrentService.id++;
            jsonStr = gendaqFuncs[methodIndex][1](gendaqCurrentService.id, gendaqCurrentService.name, i);
            this.emit('gendaq-send', jsonStr);
        }
    }
    
    startPreview() {
        gendaqCurrentService.name = "StartPreview";
        gendaqCurrentService.id++;
        var methodIndex = MethodLookup(gendaqCurrentService.name);
        jsonStr = gendaqFuncs[methodIndex][1](gendaqCurrentService.id, gendaqCurrentService.name);
        this.emit('gendaq-send', jsonStr);
    }
    
    stopPreview() {
        gendaqCurrentService.name = "StopPreview";
        gendaqCurrentService.id++;
        var methodIndex = MethodLookup(gendaqCurrentService.name);
        jsonStr = gendaqFuncs[methodIndex][1](gendaqCurrentService.id, gendaqCurrentService.name);
        this.emit('gendaq-send', jsonStr);
    }
    
    requestSnapshot() {
        gendaqCurrentService.name = "RequestSnapshot";
        gendaqCurrentService.id++;
        var methodIndex = MethodLookup(gendaqCurrentService.name);
        jsonStr = gendaqFuncs[methodIndex][1](gendaqCurrentService.id, gendaqCurrentService.name);
        this.emit('gendaq-send', jsonStr);
    }
    
    connect() {
        //connect to gendaq API
        gendaqCurrentService.name = "Connect";
        gendaqCurrentService.id++;
        var methodIndex = MethodLookup(gendaqCurrentService.name);
        jsonStr = gendaqFuncs[methodIndex][1](gendaqCurrentService.id, gendaqCurrentService.name);
        this.emit('gendaq-send', jsonStr);
    }

    disconnect() {
        //disconnect from gendaq API
        gendaqCurrentService.name = "Disconnect";
        gendaqCurrentService.id++;
        var methodIndex = MethodLookup(gendaqCurrentService.name);
        jsonStr = gendaqFuncs[methodIndex][1](gendaqCurrentService.id, gendaqCurrentService.name);
        this.emit('gendaq-send', jsonStr);
    }

    getCurrentServiceId(){
        return gendaqCurrentService.id;
    }

    getCurrentServiceName(){
        return gendaqCurrentService.name;
    }
}

module.exports = GenDaqAPI;