const net = require('net');
const tools = require('./tools');
const EventEmitter = require('events');

const HOST = process.env.GENDAQ_HOST || '127.0.0.1'
const PORT = 8006;
const PORT_FIELDDBUS = 8007;
const api_version = 1195638786;

var client = null;
var connected_gendaq = false;
let gendaqConnectionCtrl = null;

class GenDaqConnection extends EventEmitter {
    connect() {
        if (!connected_gendaq) {
            initializeConnection()
        }
    }
    disconnect() {        
        client.end();
        client.destroy()
        connected_gendaq = false;
    }
    isConnected() {
        return connected_gendaq;
    }
    send(json_rqs) {
        // Write a message to the socket as soon as the client is connected, the server will receive it as message from the client
        var arrUint32 = new Uint32Array(2);
        arrUint32[0] = json_rqs.length + 1;
        arrUint32[1] = Number(api_version);

        var bufData = new Buffer(arrUint32.buffer);
        bufData = tools.Swap32(bufData);

        client.write(bufData);
        client.write(json_rqs);

        var arrUint8 = new Uint8Array(1);
        arrUint8[0] = 0x00;
        var bufTerminator = new Buffer(arrUint8.buffer);
        client.write(bufTerminator);
    }
    setInstance(instance) {
        gendaqConnectionCtrl = instance;
    }
    emitResponseData(rsp_data) {
        gendaqConnectionCtrl.emit('gendaq-rsp', rsp_data);
    }
    emitResponseConnected() {
        connected_gendaq = true;
        gendaqConnectionCtrl.emit('gendaq-connected');
    }
    emitResponseDisconnected() {
        connected_gendaq = false;
        gendaqConnectionCtrl.emit('gendaq-disconnected');
    }
    emitResponseConnectError() {
        connected_gendaq = false;
        gendaqConnectionCtrl.emit('gendaq-connect-error');
    }
}

function initializeConnection() {
    client = new net.Socket()
    client.connect(PORT, HOST, function () {
        console.log('CONNECTED TO: ' + HOST + ':' + PORT);
        gendaqConnectionCtrl.emit('gendaq-connected');
    });

    // Add a 'close' event handler for the client socket
    client.on('close', function () {
        console.log('Connection closed');
        gendaqConnectionCtrl.emitResponseDisconnected();
        client.destroy()
    });

    // Add a 'error' event handler for the client socket
    client.on('error', function (ex) {
        console.log('Connection error');
        //console.log(ex);
        gendaqConnectionCtrl.emitResponseConnectError();
        client.destroy()
    });

    // Add a data handler for the client socket
    client.on('data', function (data) {
        var json_start = data.indexOf("{");
        //check if we have a json response
        if (json_start >= 0) {
            let data_response = data.toString().substring(json_start, data.length - 1);//extra null byte at the end
            console.log("Main - Server response: " + data_response);
            //connection.sendUTF(json_response);

            //check if we have more than one json in the same stream
            let response_split = data_response.split("GD");
            response_split.forEach(element => {
                json_start = element.indexOf("{");
                let json_end = element.lastIndexOf("}");
                let json_rsp = element.substring(json_start, json_end + 1);
                //send event to interface class
                try {
                    let a = JSON.parse(json_rsp);
                    gendaqConnectionCtrl.emitResponseData(a);
                } catch (e) {
                    console.log("Main - JSON response error: " + json_rsp + e);
                    gendaqConnectionCtrl.emitResponseData({});
                }
            });
        }
    });
}

//exports
module.exports = GenDaqConnection;