/* 
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

const EventEmitter = require('events');
const GenDaqConnection = require('./connection');
const tools = require('./tools');
const gendaqConnectionCtrl = new GenDaqConnection();
gendaqConnectionCtrl.setInstance(gendaqConnectionCtrl);
const GenDaqAPI = require('./api');
const dashboards_conf = require('../confs/config.conf');
const gendaqapi = new GenDaqAPI();
let gendaqDataDispatcher = null;
const stateMachineTimeout = 500;
let gendaqStatus = "disconnected";
let db_data = null

//holder for gendaq data
let gendaqSessionObj = {};
gendaqSessionObj.dataArr = [];
gendaqSessionObj.dataNameUnitArr = [];

class GenDaqDataDispatcher extends EventEmitter{
    newDataEvent(){
        //gendaqDataDispatcher.emit('evt-new-data', dashboard_data);
        db_data.measures.updateSnapshotMeasures(dashboard_data)
    }
    noDataEvent(){

    }
    errorConnecting(gendaqStatus){
        gendaqDataDispatcher.emit(gendaqStatus);
        this.newDataEvent()
    }
    disconnected(gendaqStatus){
        gendaqDataDispatcher.emit(gendaqStatus);
        this.newDataEvent()
    }
    setInstance(instance, db){
        gendaqDataDispatcher = instance;
        db_data = db
    }
}

gendaqConnectionCtrl.on('gendaq-connected', function () {
    console.log("Connected to gendaq and ready for commands");
    //Connect to gendaq API
    gendaqapi.connect();
});

gendaqConnectionCtrl.on('gendaq-disconnected', function () {
    gendaqStatus = "disconnected";
    dashboard_data = {};
    gendaqDataDispatcher.disconnected(gendaqStatus);
});

gendaqConnectionCtrl.on('gendaq-connect-error', function () {
    gendaqStatus = "connect-error";
    dashboard_data = {};
    gendaqDataDispatcher.errorConnecting(gendaqStatus);
});

//State Machine 
//gendaq connection event
gendaqConnectionCtrl.on('gendaq-rsp', function (obj) {
    //console.log(obj);

    if (!obj)
        return;

    switch (gendaqapi.getCurrentServiceName()) {
        case "Connect":
            {
                if (obj.result) {
                    if (gendaqapi.getCurrentServiceId() == obj.id) {
                        gendaqSessionObj.dataArr = [];
                        gendaqSessionObj.dataNameUnitArr = [];
                        dashboard_data = {};
                        gendaqStatus = "connected-api";
                        //move to next execution
                        gendaqapi.stopPreview();
                        gendaqapi.getFieldBusDataCount();
                    }
                } else {
                    gendaqStatus = "connected";
                    setTimeout(function () { gendaqapi.connect() }, stateMachineTimeout);
                }
                break;
            }
        case "GetFieldBusDataCount":
            {
                if (obj.result && obj.result.DataCount) {
                    gendaqSessionObj.DataCount = obj.result.DataCount;
                    if (gendaqapi.getCurrentServiceId() == obj.id){//move to next execution
                        if(gendaqSessionObj.DataCount > 0)
                            gendaqapi.getFieldBusDataNameAndUnit(gendaqSessionObj.DataCount);
                        else {
                            gendaqStatus = "data-error";
                            dashboard_data = {};
                            gendaqDataDispatcher.newDataEvent();
                        }
                    }

                }
                break;
            }
        case "GetFieldBusDataNameAndUnit":
            {
                if (obj.result && obj.result.DataName) {
                    gendaqSessionObj.dataNameUnitArr.push(obj.result);
                    if (gendaqapi.getCurrentServiceId() == obj.id) {
                        //move to next execution
                        mapDataToDashboard();
                        setTimeout(function () { gendaqapi.startPreview() }, stateMachineTimeout);
                    }
                }
                break;
            }
        case "StartPreview":
            {
                if (obj.result) {
                    if (gendaqapi.getCurrentServiceId() == obj.id) {
                        //move to next execution
                        setTimeout(function () { gendaqapi.requestSnapshot() }, stateMachineTimeout);
                    }
                }
                break;
            }
        case "RequestSnapshot":
            {
                if (obj.result) {
                    gendaqSessionObj.TimeStamp = obj.result.TimeStamp;
                    gendaqSessionObj.data = obj.result.Data;
                    gendaqStatus = "receiving-data";
                    saveNewSnapshotToInternalData(gendaqSessionObj.data, gendaqSessionObj.TimeStamp);
                    setTimeout(function () { gendaqapi.requestSnapshot() }, stateMachineTimeout);
                } else {
                    //error requesting, reset
                    gendaqStatus = "data-error";
                    dashboard_data = {};
                    gendaqDataDispatcher.newDataEvent();
                    //setTimeout(function () { gendaqapi.getFieldBusDataCount() }, stateMachineTimeout);
                }
                break;
            }
        default:
            break;
    }
});

gendaqapi.on('gendaq-send', function (data) {
    console.log("Sending - " + data);
    gendaqConnectionCtrl.send(data);
});

function mapDataToDashboard() {
    let dash = dashboards_conf.dashboards;
    let dash_found = false;

    for (i = 0; i < dash.length; i++) {
        dashboard_data = dash[i];        
        
        for (j = 0; j < dash[i].objs.length; j++) {            
            let pos = tools.findFormulaIndexByName(dash[i].objs[j].name, gendaqSessionObj.dataNameUnitArr);
            if(pos < 0){
                dash_found = false;
                break;
            } else {
                dash_found = true;
                dashboard_data.objs[j].dataIndex = pos;
                dashboard_data.objs[j].unit = gendaqSessionObj.dataNameUnitArr[pos].DataUnit;
            }
        }
        if (dash_found){
            break;
        }
    }

    if(!dash_found){
        dashboard_data = {};
        dashboard_data.name = dash[dash.length - 1].name;//get name from last entry in the config file
        dashboard_data.objs = [];

        gendaqSessionObj.dataNameUnitArr.forEach((element, i) => {
            let entry = { name: element.DataName, text: element.DataName, dataIndex: i, unit: element.DataUnit };
            dashboard_data.objs.push(entry);
        });
    }
    //console.log(dashboard_data);
}

function saveNewSnapshotToInternalData(array, timestamp) {
    dashboard_data.objs.forEach(element => {
        if (array[element.dataIndex])
            element.value = array[element.dataIndex];
    });

    //save timestamp, special one
    dashboard_data.timestamp = timestamp;
    gendaqDataDispatcher.newDataEvent();
}

function start() {
    if (!gendaqConnectionCtrl.isConnected()) {
        gendaqConnectionCtrl.connect();
    }
}

function stop() {
    gendaqapi.disconnect();
    setTimeout(function () { gendaqConnectionCtrl.disconnect() }, 1000);
    gendaqStatus = "disconnected";
}

function getStatus() {
    return gendaqStatus;
}

module.exports.start = start;
module.exports.stop = stop;
module.exports.getStatus = getStatus;
module.exports.GenDaqDataDispatcher = GenDaqDataDispatcher;

