const { exec }  = require("child_process");
const os = require('os');

let db = null
let logger = null
const fileUpgradePath = '/tmp/hbm-genseries-hbmi.ipk'

module.exports = function (){

    function initializeDeviceInformation(db_data, log){
        db = db_data
        logger = log

        getDeviceType()
        getDeviceName()
        getDeviceNetwork()
    }

    function getDeviceType(){
        let type = "PC"
        exec("./misc/mainframe_type.sh", (error, stdout, stderr) => {
            if (error) {
                logger.error(`error: ${error.message}`);
            }
            else if (stderr) {
                logger.error(`stderr: ${stderr}`);
                return;
            }
            else {
                type = stdout;
            }

            logger.info("Running on device: " + type)
            db.device.setDeviceType(type)
        });
    }

    function getDeviceName(){
        let name = "Not available"
        exec("uci show genseries.network.name", (error, stdout, stderr) => {
            if (error) {
                logger.error(`error: ${error.message}`);
            }
            else if (stderr) {
                logger.error(`stderr: ${stderr}`);
                return;
            }
            else {
                var rslt = stdout;
                var rslt_split = rslt.split("'")
                if(rslt_split[1])
                    name = rslt_split[1]
            }

            logger.info("Device name: " + name)
            db.device.setDeviceName(name)
        });
    }

    function getDeviceNetwork(){
        db.device.setDeviceNetwork(os.networkInterfaces())
    }

    async function upgradeHMIdevice(path){

        //check file if has correct security encryption
        let rsltSSL = await execShellCommand('openssl enc -d -aes-256-cbc -pbkdf2 -iter 100000 -salt -in ' + path + ' -out ' + fileUpgradePath + ' -pass file:/usr/share/hbm/openwrt-hbm-im3-hmi.key')
        let rsltOPKG = await execShellCommand('opkg install --force-reinstall ' + fileUpgradePath)

        return (rsltSSL == true && rsltOPKG == true)
    }

    async function getAppSwVersion(){

        const uciAppVersion = 'hmi.build.version'
        let appVersion = await execShellCommandWithRslt('uci show ' + uciAppVersion)

        //error getting version
        if(appVersion == false){
            //try to get it from package.json
            var pjson = require('../package.json');
            return ( pjson != null && pjson.version != null) ? pjson.version : 'x.x.x'
        }
        
        //get version, split result 
        var splitRslt = appVersion.split('\'')
        if(splitRslt[1] != null){
            return splitRslt[1]             
        }
        else
            return 'x.x.x'
    }

    /**
     * Executes a shell command and return it as a Promise.
     * @param cmd {string}
     * @return {Promise<bool>}
     */
    function execShellCommand(cmd) {
        return new Promise((resolve, reject) => {
            exec(cmd, (error, stdout, stderr) => {
            if (error) {
                logger.error(`error: ${error.message}`)
                resolve(false)
            } else {
                resolve(true);
            }
            
            });
        });
    }

    /**
     * Executes a shell command and return it as a Promise.
     * @param cmd {string}
     * @return {Promise<string>}
     */
    function execShellCommandWithRslt(cmd) {
        return new Promise((resolve, reject) => {
            exec(cmd, (error, stdout, stderr) => {
            if (error) {
                logger.error(`error: ${error.message}`)
                resolve(false)
            } else {
                resolve(stdout);
            }
            
            });
        });
    }

    return {
        initializeDeviceInformation : initializeDeviceInformation,
        upgradeHMIdevice : upgradeHMIdevice,
        getDeviceNetwork : getDeviceNetwork,
        getDeviceName : getDeviceName,
        getDeviceType : getDeviceType,
        getAppSwVersion : getAppSwVersion
    }    
}