

// Realtime chart
// ------------------------------
$(window).on("load", function(){

    // We use an inline data source in the example, usually data would
    // be fetched from a server

    var updateInterval = 200;
    var now = 0;
    var totalPoints = 200;
    var data_CurrentSum = [];
    var data_CurrentSumFund = [];
    var data_VoltageSum = [];
    var data_VoltageSumFund = [];

    function getData() {
        $.ajax({
            dataType: "json",
            url: '/api/measures/list/edrive',
            success: update
          });
    }

    function initData() {        
        for (var i = 0; i < totalPoints; i++) {
            var temp = [now += 1, 0];
    
            data_CurrentSum.push(temp);
            data_CurrentSumFund.push(temp);
            data_VoltageSum.push(temp);
            data_VoltageSumFund.push(temp);
        }
    }

    var options_currents = {
        grid: {
            borderWidth: 1,
            borderColor: "transparent",
            color: '#999',
            minBorderMargin: 20,
            labelMargin: 10,
            margin: {
                top: 8,
                bottom: 20,
                left: 20
            },
        },
        series: {
            shadowSize: 0,   // Drawing is faster without shadows
            lines: {
                fill: false,
                fillColor: { colors: [ { opacity: 0.8 }, { opacity: 0.1 } ] }
            }
        },
        yaxis: {
            min: 0
        },
        xaxis: {
            show: false
        },
        legend: {
            show: true,
            position: "ne",// or "nw" or "se" or "sw"
            labelFormatter: function(label, series) {
                // series is the series object for the label
                return '<a>&Sigma; ' + label + '</a>';
            }
            
        },
        colors: ['#FF7D4D']
    };

    var options_voltages = {
        grid: {
            borderWidth: 1,
            borderColor: "transparent",
            color: '#999',
            minBorderMargin: 20,
            labelMargin: 10,
            margin: {
                top: 8,
                bottom: 20,
                left: 20
            },
        },
        series: {
            shadowSize: 0,   // Drawing is faster without shadows
            lines: {
                fill: false,
                fillColor: { colors: [ { opacity: 0.8 }, { opacity: 0.1 } ] }
            }
        },
        yaxis: {
            min: 0
        },
        xaxis: {
            show: false
        },
        legend: {
            show: true,
            position: "ne",// or "nw" or "se" or "sw"
            labelFormatter: function(label, series) {
                // series is the series object for the label
                return '<a>&Sigma; ' + label + '</a>';
            }
            
        },
        colors: ['#FF7D4D']
    };

    function update(_data) 
    {
        data_CurrentSum.shift();
        data_CurrentSumFund.shift();
        data_VoltageSum.shift();
        data_VoltageSumFund.shift();

        var rslt = _data[0];
        data_CurrentSum.push([now, formatNumber(rslt.CurrentSum).value]);
        data_CurrentSumFund.push([now, formatNumber(rslt.CurrentFundSum).value]);
        data_VoltageSum.push([now, formatNumber(rslt.VoltageSum).value]);
        data_VoltageSumFund.push([now, formatNumber(rslt.VoltageFundSum).value]);
        now++;//used to simulate timestamp, this should be changed

        dataset_currents = [
            { label: "Current: " + formatNumber(rslt.CurrentSum).value + " A", data: data_CurrentSum },
            { label: "Current Fundamental: " + formatNumber(rslt.CurrentFundSum).value + " A", data: data_CurrentSumFund }       
        ];

        dataset_voltages = [
            { label: "Voltage: " + formatNumber(rslt.VoltageSum).value + " V", data: data_VoltageSum },
            { label: "Voltage Fundamental: " + formatNumber(rslt.VoltageFundSum).value + " V", data: data_VoltageSumFund }       
        ];

        $.plot("#realtime_currents", dataset_currents, options_currents);
        $.plot("#realtime_voltages", dataset_voltages, options_voltages);
        // Since the axes don't change, we don't need to call plot.setupGrid()

        //plot.draw();
        setTimeout(getData, updateInterval);
    }

    initData();
    getData();
});